@@ -24,7 +24,7 @@
 typedef enum {
 	cctyp_unkn = 0,			/* Unknown */
 	cctyp_1,				/* Chromecast 1 or General Video */
-	cctyp_2,				/* Chromecast 2 */
+	cctyp_2,				/* Chromecast 2 (Can't be detected though - id will be cctyp_1) */
 	cctyp_Audio,			/* Chromecast Audio or General Audio */
 	cctyp_Ultra,			/* Chromecast Ultra */
 	cctyp_Other				/* Non Video/Audio output device */
@@ -42,7 +42,9 @@ struct _ccast_id {
 /* Get a list of Video out capable Chromecasts. Return NULL on error */
 /* Last pointer in array is NULL */ 
 /* Takes 0.5 second to return */
-ccast_id **get_ccids(void);
+ccast_id **get_ccids(
+void
+);
 
 /* Free up what get_ccids returned */
 void free_ccids(ccast_id **ids);
