@@ -94,7 +94,7 @@ void (*prog)(void *pdata, int perc),		/* Optional progress percentage callback *
 void *pdata				/* Opaque data needed by prog() */
 ) {
 	int i;
-	double **dmtx, *_dmtx[10], __dmtx[10 * 10] = { 0.0 };		/* Direction vector */
+	double **dmtx, *_dmtx[10], __dmtx[10 * 10] = { 0.0 };		/* Direction vectors */
 	double *spt, _spt[10];			/* Sarting point before exploring all the directions */
 	double *xpt, _xpt[10];			/* Extrapolated point */
 	double *svec, _svec[10];		/* Search vector */
@@ -136,7 +136,7 @@ void *pdata				/* Opaque data needed by prog() */
 	retv = (*func)(fdata, cp);
 
 //printf("~1 ### initial retv = %f\n",retv);
-	/* Itterate untill we converge on a solution, or give up. */
+	/* Itterate until we converge on a solution, or give up. */
 	for (iter = 1; iter < maxit; iter++) {
 		int j;
 		double lretv;			/* Last function return value */
@@ -159,14 +159,14 @@ void *pdata				/* Opaque data needed by prog() */
 			lretv = retv;
 			retv = linmin(cp, svec, di, ftol, func, fdata);
 
-			/* Record bigest function decrease, and dimension it occured on */
+			/* Record bigest function decrease, and direction it occured on */
 			if (fabs(lretv - retv) > del) {
 				del = fabs(lretv - retv);
 				ibig = i;
 			}
 		}
 
-//printf("~1 ### biggest change was dir %d  by %f\n", ibig, del);
+//printf("~1 ### biggest change was dir %d by %f\n", ibig, del);
 
 #ifdef ABSTOL
 		stopth = ftol;				/* Absolute tollerance */
@@ -186,7 +186,8 @@ void *pdata				/* Opaque data needed by prog() */
 			}
 
 		}
-		/* If we have had at least one change of direction and */
+
+		/* If we have made at least one pass through all directions and */
 		/* reached a suitable tollerance, then finish */
 		if (iter > 1 && curdel <= stopth) {
 //printf("~1 ### stopping on itter %d because curdel %f <= stopth %f\n",iter, curdel,stopth);
@@ -196,6 +197,7 @@ void *pdata				/* Opaque data needed by prog() */
 		PDBG(("Not stopping because curdel %f > stopth %f\n",curdel,stopth))
 
 //printf("~1 ### recomputing direction\n");
+		/* Compute overall direction minimization moved in */
 		for (i = 0; i < di; i++) {
 			svec[i] = cp[i] - spt[i];	/* Average direction moved after minimization round */
 			xpt[i]  = cp[i] + svec[i];	/* Extrapolated point after round of minimization */
@@ -203,7 +205,7 @@ void *pdata				/* Opaque data needed by prog() */
 		}
 //printf("~1 ### new dir = %f %f\n", svec[0],svec[1]);
 
-		/* Function value at extrapolated point */
+		/* Function value at extrapolated point in overall direction moved in */
 		lretv = (*func)(fdata, xpt);
 
 		if (lretv < pretv) {			/* If extrapolation is an improvement */
@@ -223,7 +225,7 @@ void *pdata				/* Opaque data needed by prog() */
 				}
 			}
 		}
-	}
+	}		/* Continue itterating */
 
 //printf("~1 iters = %d\n",iter);
 
@@ -609,14 +611,24 @@ void *pdata				/* Opaque data needed by prog() */
 	}
 
 	CDBG(("conjgrad with di %d\n", di))
+	CDBG((" cp = %s\n", debPdv(di,cp)))
+	CDBG(("  s = %s\n", debPdv(di,s)))
 
 	if (prog != NULL)		/* Report initial progress */
 		prog(pdata, pc);
 
 	/* Initial function and gradient evaluation */
+	CDBG((" calling dfunc\n"))
 	retv = (*dfunc)(fdata, svec, cp);
-	if (retv == DFUNC_NRV) 
+
+	CDBG((" returned %e and d %s\n",retv,debPdv(di,svec)))
+
+	if (retv == DFUNC_NRV) { 
+		CDBG((" calling func\n"))
 		retv = (*func)(fdata, cp);
+	} else {
+		CDBG((" dfunc returns func value %f\n",retv))
+	}
 
 	/* svec[] seems to be large after this. Compute scaled version that */
 	/* has maximum of s[] so that line search is guided by the search radius. */
@@ -625,11 +637,17 @@ void *pdata				/* Opaque data needed by prog() */
 		if (rat > brat)
 			brat = rat;
 	}
-	svec_sca = 1.0/brat;
+
+	svec_sca = 1.0;
+	if (brat > DBL_EPSILON) 
+		svec_sca /= brat;
+
+	CDBG((" svec_sca = %f\n",svec_sca))
 
 	/* Initial vector setup */
 	for (i = 0; i < di; i++) {
-		svec[i] = gvec[i] = hvec[i] = -svec[i];			/* Inverse gradient */
+		gvec[i] = -svec[i];
+		svec[i] = hvec[i] = gvec[i];	/* Set G & H to -ve gradient */
 		ssvec[i] = svec[i] * svec_sca;	/* Scale the search vector to s[] size */
 	}
 
@@ -681,12 +699,13 @@ void *pdata				/* Opaque data needed by prog() */
 
 		/* Compute gamma */
 		for (gamnum = gamden = 0.0, i = 0; i < di; i++) {
-			gamnum += svec[i] * (gvec[i] + svec[i]);
 			gamden += gvec[i] * gvec[i];
+//			gamnum += svec[i] * svec[i];						/* Flecher-Reeves */
+			gamnum += svec[i] * (gvec[i] + svec[i]);			/* Polak-Ribiere */
 		}
 
 		CDBG((" gamnum = %f, gamden = %f\n", gamnum,gamden));
-		if (gamden == 0.0) {		/* Gradient is exactly zero */
+		if (fabs(gamden) < DBL_EPSILON) {		/* Gradient is exactly zero */
 			CDBG(("conjrad: gradient is exactly zero\n"))
 			break;
 		}
