@@ -15,6 +15,16 @@
 /*
  * TTBD:
  *	
+ *		Change plot_info contents to be a single array of draw objects.
+ *		Object is poly type, one of three:
+
+ *		1) line: color + single point + optional pointer to array of n points
+ *		2) vectors: color + point pair + optional pointer to array of n point pairs.
+ *		3) symbols: color + point + symbol + text
+ *
+ *		Change plot_g to match, and then re-implement all other functions in
+ *      terms of these objects.
+ *
  *		Allow for a window title for each plot.
  *
  *		Put all state information in plot_info (window handles etc.)
@@ -74,10 +84,10 @@ int plot_colors[MXGPHS][3] = {
 	{ 112, 255, 161},	/* Lime */
 	{ 255, 191,  80},	/* Pink */
 
-	{   0, 100, 100},	/* ???? */
-	{ 100,   0, 100},	/* ???? */
-	{ 100, 100,   0},	/* ???? */
-	{ 100,   0,   0}	/* ???? */
+	{   0, 100, 100},	/* Full Cyan */
+	{ 100,   0, 100},	/* Full Magenta */
+	{ 100, 100,   0},	/* Full Yellow */
+	{ 100,   0,   0}	/* Full Red */
 };
 
 struct _plot_info {
@@ -113,7 +123,7 @@ struct _plot_info {
 	double *xp, *yp;				/* Symbol position - default no symbol or text */
 	plot_sym *tp;					/* Symbol type - default none */
 	plot_col *pcols;				/* Symbol color - default plot colors */
-	char **ptext;					/* Text near symbol - defaul none */
+	char **ptext;					/* Text near symbol - default none */
 	int p;							/* Number of symbols */
 
 	/* Plot instance information */
@@ -503,7 +513,7 @@ int m) {
 }
 
 /* Public routines */
-/* Plot up to 12 graphs + optional crosses */
+/* Plot up to MXGPHS graphs + optional crosses */
 int
 do_plotNpwz(
 double *x,		/* X coord */
@@ -1028,6 +1038,71 @@ int get_vxyix_g(plot_g *g) {
 }
 
 
+/* Start a line that will be implemented as vectors. */
+void start_line_g(plot_g *g, double x, double y, float *rgb) {
+	g->lx = x;
+	g->ly = y;
+	g->lrgb[0] = rgb[0];
+	g->lrgb[1] = rgb[1];
+	g->lrgb[2] = rgb[2];
+}
+
+/* Continue a line that will be implemented as vectors */
+void extend_line_g(plot_g *g, double x, double y) {
+	add_vec_g(g, g->lx, g->ly, x, y, g->lrgb);
+	g->lx = x;
+	g->ly = y;
+}
+
+/* Return the bounding box of all the current elements locations */
+void get_bounds_g(plot_g *g, double *pxmin, double *pxmax, double *pymin, double *pymax) {
+	double xmin = 1e38, xmax = -1e38, ymin = 1e38, ymax = -1e38;
+	int i;
+
+	for (i = 0; i < g->o; i++) {
+		if (g->x1[i] < xmin)
+			xmin = g->x1[i];
+		if (g->x1[i] > xmax)
+			xmax = g->x1[i];
+
+		if (g->y1[i] < ymin)
+			ymin = g->y1[i];
+		if (g->y1[i] > ymax)
+			ymax = g->y1[i];
+
+		if (g->x2[i] < xmin)
+			xmin = g->x2[i];
+		if (g->x2[i] > xmax)
+			xmax = g->x2[i];
+
+		if (g->y2[i] < ymin)
+			ymin = g->y2[i];
+		if (g->y2[i] > ymax)
+			ymax = g->y2[i];
+	}
+
+	for (i = 0; i < g->p; i++) {
+		if (g->x3[i] < xmin)
+			xmin = g->x3[i];
+		if (g->x3[i] > xmax)
+			xmax = g->x3[i];
+
+		if (g->y3[i] < ymin)
+			ymin = g->y3[i];
+		if (g->y3[i] > ymax)
+			ymax = g->y3[i];
+	}
+
+	if (pxmin != NULL)
+		*pxmin = xmin;
+	if (pxmax != NULL)
+		*pxmax = xmax;
+	if (pymin != NULL)
+		*pymin = ymin;
+	if (pymax != NULL)
+		*pymax = xmax;
+}
+
 /* Plot, but don't clear (i.e. free) lists */
 void do_plot_g(
 plot_g *g,
@@ -3210,13 +3285,22 @@ int main(int argc, char *argv[]) {
 	printf("Doing general vector plot with colors using plot_g\n");
 	for (i = 0; i < 4; i++)
 		add_vec_g(&gg, Bx1[i], By1[i], Bx2[i], By2[i], mcols[i].rgb);
-
 	do_plot_g(&gg, 0.0, 0.0, 0.0, 0.0, 1.0, 0, 1);
 
 	printf("Doing general symbols and text using plot_g\n");
 	for (i = 0; i < 8; i++)
 		add_sym_g(&gg, Bx3[i], By3[i], syms[i], mcols[i].rgb, ptext[i]);
+	do_plot_g(&gg, 0.0, 0.0, 0.0, 0.0, 1.0, 0, 1);
 
+	clear_g(&gg);
+
+	printf("Doing general lines using plot_g\n");
+	start_line_g(&gg,  0.1, 0.1, mcols[0].rgb);
+	extend_line_g(&gg,  0.4, 0.2);
+	extend_line_g(&gg,  0.15, 0.5);
+	start_line_g(&gg,  0.6, 0.3, mcols[1].rgb);
+	extend_line_g(&gg,  0.3, 0.6);
+	extend_line_g(&gg,  0.7, 0.55);
 	do_plot_g(&gg, 0.0, 0.0, 0.0, 0.0, 1.0, 0, 1);
 
 	clear_g(&gg);
