@@ -31,9 +31,6 @@
 
 #include <stdio.h>
 #include <string.h>
-#if defined(__IBMC__)
-#include <float.h>
-#endif
 #include "copyright.h"
 #include "aconfig.h"
 #include "numlib.h"
@@ -69,7 +66,7 @@ usage(void) {
 	fprintf(stderr," -D              Use D50 100.0 as L*a*b* white reference\n");
 	fprintf(stderr," -c              Show CIE94 delta E values\n");
 	fprintf(stderr," -k              Show CIEDE2000 delta E values\n");
-	fprintf(stderr," -h [hist.txt]   Plot a histogram of delta E's [Optionaly save points to .txt]\n");
+	fprintf(stderr," -h [hist.txt]   Plot a histogram of delta E's [Optionally save points to .txt]\n");
 	fprintf(stderr," -s              Sort patch values by error\n");
 	fprintf(stderr," -w              create PCS %s vector visualisation (measured%s)\n",vrml_format(),vrml_ext());
 	fprintf(stderr," -W              create PCS %s marker visualisation (measured%s)\n",vrml_format(),vrml_ext());
@@ -131,6 +128,7 @@ int main(int argc, char *argv[])
 	ccmx *cmx = NULL;					/* Colorimeter Correction Matrix */
 	char gprofname[MAXNAMEL+1] = "\000";  /* Gamut limit profile name */
 	icmFile *fp = NULL;
+	icmErr err = { 0, { '\000'} };
 	icc *icco = NULL;
 	xicc *xicco = NULL;
 	icxLuBase *luo = NULL;
@@ -164,6 +162,7 @@ int main(int argc, char *argv[])
 	char out_name[MAXNAMEL+4+1]; /* VRML/X3D name */
 	vrml *wrl = NULL;
 
+
 	int i, j, n;
 
 	if (argc <= 1)
@@ -439,6 +438,7 @@ int main(int argc, char *argv[])
 	if (fa >= argc || argv[fa][0] == '-') usage();
 	strncpy(cg[1].name,argv[fa],MAXNAMEL); cg[1].name[MAXNAMEL] = '\000';
 
+
 	/* Create VRML/X3D base name */
 	{
 		char *xl;
@@ -455,15 +455,15 @@ int main(int argc, char *argv[])
 	if (gprofname[0] != '\000') {
 		int rv;
 
-		if ((fp = new_icmFileStd_name(gprofname,"r")) == NULL)
-			error ("Can't open file '%s'",gprofname);
+		if ((fp = new_icmFileStd_name(&err,gprofname,"r")) == NULL)
+			error ("Can't open file '%s' (0x%x, '%s')",gprofname,err.c,err.m);
 	
-		if ((icco = new_icc()) == NULL)
-			error ("Creation of ICC object failed");
+		if ((icco = new_icc(&err)) == NULL)
+			error ("Creation of ICC object failed (0x%x, '%s')",err.c,err.m);
 	
 		if ((rv = icco->read(icco,fp,0)) != 0)
 			error("Reading profile '%s' failed failed with error %d:'%s'\n",
-		     	       gprofname, icco->errc,  icco->err);
+		     	       gprofname, icco->e.c,  icco->e.m);
 
 		if (icco->header->deviceClass != icSigInputClass
 		 && icco->header->deviceClass != icSigDisplayClass
@@ -477,7 +477,7 @@ int main(int argc, char *argv[])
 		/* Get a expanded color conversion object */
 		if ((luo = xicco->get_luobj(xicco, ICX_CLIP_NEAREST | ICX_FAST_SETUP,
 		    icmFwd, icRelativeColorimetric, icSigXYZData, icmLuOrdNorm, NULL, NULL)) == NULL)
-			error ("%d, %s",xicco->errc, xicco->err);
+			error ("%d, %s",xicco->e.c, xicco->e.m);
 	}
 
 	/* Colorimeter Correction Matrix */
@@ -486,7 +486,7 @@ int main(int argc, char *argv[])
 			error("new_ccmx failed\n");
 		if (cmx->read_ccmx(cmx,ccmxname))
 			error("Reading Colorimeter Correction Matrix file '%s' failed with error %d:'%s'\n",
-		     	       ccmxname, cmx->errc,  cmx->err);
+		     	       ccmxname, cmx->e.c,  cmx->e.m);
 	}
 
 
@@ -508,7 +508,7 @@ int main(int argc, char *argv[])
 		DBG(("Opening file '%s'\n",cg[n].name))
 
 		if (cgf->read_name(cgf, cg[n].name))
-			error("CGATS file '%s' read error : %s",cg[n].name,cgf->err);
+			error("CGATS file '%s' read error : %s",cg[n].name,cgf->e.m);
 	
 		if (cgf->ntables < 1)
 			error ("Input file '%s' doesn't contain at least one table",cg[n].name);
@@ -1464,3 +1464,5 @@ int main(int argc, char *argv[])
 }
 
 
+
+
