@@ -1,6 +1,6 @@
 
 /* 
- * Argyll Color Correction System
+ * Argyll Color Management System
  *
  * Read in the raw data from a Kodak print profile,
  * and convert it into a .ti3 CGATs format suitable for
@@ -74,32 +74,28 @@ int main(int argc, char *argv[])
 	struct tm *tsp = localtime(&clk);
 	char *atm = asctime(tsp); /* Ascii time */
 
+
 	error_program = "kodak2ti3";
 
 	if (argc <= 1)
 		usage();
 
 	/* Process the arguments */
-	for(fa = 1;fa < argc;fa++)
-		{
+	for (fa = 1;fa < argc;fa++) {
 		nfa = fa;					/* skip to nfa if next argument is used */
-		if (argv[fa][0] == '-')		/* Look for any flags */
-			{
+		if (argv[fa][0] == '-')	{	/* Look for any flags */
 			char *na = NULL;		/* next argument after flag, null if none */
 
 			if (argv[fa][2] != '\000')
 				na = &argv[fa][2];		/* next is directly after flag */
-			else
-				{
-				if ((fa+1) < argc)
-					{
-					if (argv[fa+1][0] != '-')
-						{
+			else {
+				if ((fa+1) < argc) {
+					if (argv[fa+1][0] != '-') {
 						nfa = fa + 1;
 						na = argv[nfa];		/* next is seperate non-flag argument */
-						}
 					}
 				}
+			}
 
 			if (argv[fa][1] == '?')
 				usage();
@@ -122,14 +118,15 @@ int main(int argc, char *argv[])
 				verb = 1;
 			else 
 				usage();
-			}
+		}
 		else
 			break;
-		}
+	}
 
 	/* Get the file name argument */
 	if (fa >= argc || argv[fa][0] == '-') usage();
 
+
 	strcpy(inname,argv[fa++]);
 	strcat(inname,".pat");
 
@@ -195,6 +192,7 @@ int main(int argc, char *argv[])
 		                         labv[0], labv[1], labv[2]);
 	}
 
+
 	{
 		double wp[3];			/* Paper white XYZ */
 		double D50wp[3] 		/* D50 white point Kodak uses */
@@ -240,7 +238,7 @@ int main(int argc, char *argv[])
 	}
 
 	if (ocg->write_name(ocg, outname))
-		error("Write error : %s",ocg->err);
+		error("Write error : %s",ocg->e.m);
 
 	ocg->del(ocg);		/* Clean up */
 
@@ -1271,3 +1269,5 @@ void close_928(FILE *fp) {
 
 
 
+
+
