@@ -23,9 +23,6 @@
 #include <math.h>
 #include <sys/types.h>
 #include <time.h>
-#if defined(__IBMC__) && defined(_M_IX86)
-#include <float.h>
-#endif
 #include "copyright.h"
 #include "aconfig.h"
 #include "numlib.h"
@@ -82,17 +79,14 @@ int main(int argc, char *argv[])
 	double aerr = 0.0;
 	double nsamps = 0.0;
 
-#if defined(__IBMC__) && defined(_M_IX86)
-	_control87(EM_UNDERFLOW, EM_UNDERFLOW);
-	_control87(EM_OVERFLOW, EM_OVERFLOW);
-#endif
+
 	error_program = argv[0];
 
 	if (argc <= 1)
 		usage();
 
 	/* Process the arguments */
-	for(fa = 1;fa < argc;fa++) {
+	for (fa = 1;fa < argc;fa++) {
 
 		nfa = fa;					/* skip to nfa if next argument is used */
 		if (argv[fa][0] == '-') {	/* Look for any flags */
@@ -146,12 +140,13 @@ int main(int argc, char *argv[])
 	if (fa >= argc || argv[fa][0] == '-') usage();
 	strcpy(mppname,argv[fa++]);
 
+
 	/* Open and look at the .ti3 profile patches file */
 	icg = new_cgats();				/* Create a CGATS structure */
 	icg->add_other(icg, "CTI3"); 	/* our special input type is Calibration Target Information 3 */
 
 	if (icg->read_name(icg, ti3name))
-		error("CGATS file read error : %s",icg->err);
+		error("CGATS file read error : %s",icg->e.m);
 
 	if (icg->ntables == 0 || icg->t[0].tt != tt_other || icg->t[0].oi != 0)
 		error ("Input file isn't a CTI3 format file");
@@ -242,6 +237,7 @@ int main(int argc, char *argv[])
 		}
 	}
 
+
 	if (limit > 1e-4 && limit <= (ICX_MXINKS * 100.0)) {
 		if (verb)
 			printf("Total ink limit being used is %f\n",limit);
@@ -414,7 +410,7 @@ int main(int argc, char *argv[])
 		error("Failed to create an mpp");
 
 	if (p->read_mpp(p, mppname))
-		error("Read error : %s",p->err);
+		error("Read error : %s",p->e.m);
 
 	/* Set just PCS and use XYZ model */
 	p->set_ilob(p, icxIT_default, NULL, icxOT_default, NULL, icSigLabData, 0);
@@ -587,6 +583,8 @@ int main(int argc, char *argv[])
 
 
 
+
+
 
 
 
