@@ -56,7 +56,7 @@ usage(void) {
 	fprintf(stderr," -x                16 bit output\n");
 	fprintf(stderr," -4                CMYK output\n");
 	fprintf(stderr," -g prop           Percentage towards grey (default 0%%)\n");
-	fprintf(stderr," -P                Save as PNG file (deffault TIFF)\n");
+	fprintf(stderr," -P                Save as PNG file (default TIFF)\n");
 //	fprintf(stderr," -D	               Debug primitives plot */
 	fprintf(stderr," outfile.[tif|png] Output TIFF or PNG file\n");
 	exit(1);
@@ -82,13 +82,14 @@ int main(int argc, char *argv[]) {
 	double w, h;			/* Size of page in mm */
 	int i, j;
 
+
 	error_program = "timage";
 
 	if (argc <= 1)
 		usage();
 
 	/* Process the arguments */
-	for(fa = 1;fa < argc;fa++) {
+	for (fa = 1;fa < argc;fa++) {
 
 		nfa = fa;					/* skip to nfa if next argument is used */
 		if (argv[fa][0] == '-') {	/* Look for any flags */
@@ -172,6 +173,7 @@ int main(int argc, char *argv[]) {
 	if (fa >= argc || argv[fa][0] == '-') usage();
 	strncpy(outname,argv[fa++],MAXNAMEL); outname[MAXNAMEL] = '\000';
 
+
 	res /= 25.4;				/* Convert to DPmm */ 
 
 	/* Debug chart - test each primitive in RGB space */
@@ -713,6 +715,7 @@ int main(int argc, char *argv[]) {
 		}
 	}
 
+
 #ifdef PNG_MEM
 	{
 		char *nmode = "w";
@@ -749,3 +752,5 @@ int main(int argc, char *argv[]) {
 }
 
 
+
+
