@@ -85,6 +85,16 @@ char *src
 	return 0;
 }
 
+/* Compute a simple string hash value */
+unsigned int shash(char *c) {
+	unsigned int hash = 0;
+
+	for (; *c != '\000'; c++)
+		hash = hash * 67 + (unsigned char)(*c);
+
+	return hash;
+}
+
 void
 usage(void) {
 	fprintf(stderr,"Scanin, Version %s\n",ARGYLL_VERSION_STR);
@@ -140,8 +150,7 @@ usage(void) {
 	}
 
 
-int main(int argc, char *argv[])
-{
+int main(int argc, char *argv[]) {
 	int fa,nfa;					/* current argument we're looking at */
 	static char tiffin_name[MAXNAMEL+1] = { 0 };	/* TIFF Input file name (.tif) */
 	static char datin_name[MAXNAMEL+4+1] = { 0 };	/* Data input name (.cie/.q60) */
@@ -178,13 +187,14 @@ int main(int argc, char *argv[])
 	char *errm;
 	int pnotscan = 0;		/* Number of patches that wern't scanned */
 
-	if (argc <= 1)
-		usage();
 
 	error_program = argv[0];
 
+	if (argc <= 1)
+		usage();
+
 	/* Process the arguments */
-	for(fa = 1;fa < argc;fa++) {
+	for (fa = 1;fa < argc;fa++) {
 		nfa = fa;					/* skip to nfa if next argument is used */
 		if (argv[fa][0] == '-')		/* Look for any flags */
 			{
@@ -338,6 +348,7 @@ int main(int argc, char *argv[])
 	if (fa >= argc || argv[fa][0] == '-') usage();
 	strncpy(tiffin_name,argv[fa],MAXNAMEL); tiffin_name[MAXNAMEL] = '\000';
 
+
 	/* Create a desination file path and name */
 	if (datout_name[0] == '\000'		/* Not been overridden */
 	 && (flags & SI_BUILD_REF) == 0
@@ -488,6 +499,7 @@ int main(int argc, char *argv[])
 	/* -------------------------- */
 	/* Do the operation */
 
+
 	if ((sr = do_scanrd(
 		flags,			/* option flags */
 		verb,			/* verbosity level */
@@ -580,7 +592,7 @@ int main(int argc, char *argv[])
 				printf("Writing output values to file '%s'\n",datout_name);
 				
 			if (ocg->write_name(ocg, datout_name))
-				error("Write error to '%s' : %s",datout_name,ocg->err);
+				error("Write error to '%s' : %s",datout_name,ocg->e.m);
 	
 			ocg->del(ocg);		/* Clean up */
 
@@ -607,7 +619,7 @@ int main(int argc, char *argv[])
 			icg = new_cgats();			/* Create a CGATS structure */
 			icg->add_other(icg, "CTI2"); 	/* Calibration Target Information 2 */
 			if (icg->read_name(icg, datin_name))
-				error("CGATS file '%s' read error : %s",datin_name,icg->err);
+				error("CGATS file '%s' read error : %s",datin_name,icg->e.m);
 	
 			if (icg->t[0].tt != tt_other || icg->t[0].oi != 0)
 				error("Input file '%s' isn't a CTI2 format file",datin_name);
@@ -647,7 +659,7 @@ int main(int argc, char *argv[])
 			ocg = new_cgats();			/* Create a CGATS structure */
 			ocg->add_other(ocg, "CTI3"); 	/* Calibration Target Information 3 */
 			if (ocg->read_name(ocg, datout_name))
-				error("CGATS file '%s' read error : %s",datout_name,ocg->err);
+				error("CGATS file '%s' read error : %s",datout_name,ocg->e.m);
 	
 			if (ocg->t[0].tt != tt_other || ocg->t[0].oi != 0)
 				error("Input file '%s' isn't a CTI3 format file",datout_name);
@@ -734,7 +746,7 @@ int main(int argc, char *argv[])
 				printf("Writing output values to file '%s'\n",datout_name);
 				
 			if (ocg->write_name(ocg, datout_name))
-				error("Write error to file '%s' : %s",datout_name,ocg->err);
+				error("Write error to file '%s' : %s",datout_name,ocg->e.m);
 	
 			ocg->del(ocg);		/* Clean up */
 			icg->del(icg);		/* Clean up */
@@ -745,8 +757,9 @@ int main(int argc, char *argv[])
 			cgats *icg;			/* input .ti2 cgats structure */
 			cgats *ocg;			/* input/output .ti3 cgats structure */
 			icmFile *rd_fp = NULL;	/* Image to CIE lookup */
+	icmErr err = { 0, { '\000'} };
 			icc *rd_icco = NULL;
-			icmLuBase *luo;
+			icmLuSpace *luo;
 			mpp *mlu = NULL;
 			time_t clk = time(0);
 			struct tm *tsp = localtime(&clk);
@@ -765,7 +778,7 @@ int main(int argc, char *argv[])
 			icg->add_other(icg, "CAL"); 	/* There may be a calibration too */
 		
 			if (icg->read_name(icg, datin_name))
-				error("CGATS file '%s' read error : %s",datin_name,icg->err);
+				error("CGATS file '%s' read error : %s",datin_name,icg->e.m);
 		
 			if (icg->t[0].tt != tt_other || icg->t[0].oi != 0)
 				error("Input file '%s' isn't a CTI2 format file",datin_name);
@@ -782,7 +795,7 @@ int main(int argc, char *argv[])
 			if (colm > 1) {		/* Appending information to .ti3 */
 
 				if (ocg->read_name(ocg, datout_name))
-					error("CGATS file read error on '%s': %s",datout_name, ocg->err);
+					error("CGATS file read error on '%s': %s",datout_name, ocg->e.m);
 		
 				if (ocg->t[0].tt != tt_other || ocg->t[0].oi != 0)
 					error("Input file '%s' isn't a CTI3 format file",datout_name);
@@ -836,11 +849,11 @@ int main(int argc, char *argv[])
 							error("new_xcal failed");
 						}
 						if (cal->read_cgats(cal, icg, tab, datin_name) != 0)  {
-							error("%s",cal->err);
+							error("%s",cal->e.m);
 						}
 			
 						if (cal->write_cgats(cal, ocg)) {
-							error("%s",cal->err);
+							error("%s",cal->e.m);
 						}
 			
 						cal->del(cal);
@@ -1001,23 +1014,28 @@ int main(int argc, char *argv[])
 				int rv;
 
 				/* Open up the file for reading */
-				if ((rd_fp = new_icmFileStd_name(prof_name,"r")) == NULL)
-					error("Write: Can't open file '%s'",prof_name);
+				if ((rd_fp = new_icmFileStd_name(&err,prof_name,"r")) == NULL)
+					error("Write: Can't open file '%s' (0x%x, '%s')",prof_name,err.c,err.m);
 		
-				if ((rd_icco = new_icc()) == NULL)
-					error("Read: Creation of ICC object failed");
+				if ((rd_icco = new_icc(&err)) == NULL)
+					error("Read: Creation of ICC object failed (0x%x, '%s')",err.c,err.m);
 		
 				/* Read the header and tag list */
 				if ((rv = rd_icco->read(rd_icco,rd_fp,0)) == 0) {
+					icmCSInfo ini, outi;
 		
 					/* Get the Fwd table, absolute with XYZ override */
-					if ((luo = rd_icco->get_luobj(rd_icco, icmFwd, icAbsoluteColorimetric,
+					if ((luo = (icmLuSpace *)rd_icco->get_luobj(rd_icco, icmFwd, icAbsoluteColorimetric,
 					                              icSigXYZData, icmLuOrdNorm)) == NULL) {
-						error("%d, %s",rd_icco->errc, rd_icco->err);
+						error("%d, %s",rd_icco->e.c, rd_icco->e.m);
 					}
 
 					/* Get details of conversion */
-					luo->spaces(luo, &ins, &inn, &outs, &outn, NULL, NULL, NULL, NULL, NULL);
+					luo->spaces(luo, &ini, &outi, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
+					ins = ini.sig;
+					inn = ini.nch;
+					outs = outi.sig;
+					outn = outi.nch;
 
 					/* Check that it matches what we expect */
 
@@ -1092,7 +1110,7 @@ int main(int argc, char *argv[])
 
 								/* Convert to XYZ */
 								if (luo != NULL)
-									luo->lookup(luo, xyz, P);
+									luo->lookup_fwd(luo, xyz, P);
 								else
 									mlu->lookup(mlu, xyz, P);
 
@@ -1143,7 +1161,7 @@ int main(int argc, char *argv[])
 				printf("Writing output values to file '%s'\n",datout_name);
 				
 			if (ocg->write_name(ocg, datout_name))
-				error("File '%s' write error : %s",datout_name,ocg->err);
+				error("File '%s' write error : %s",datout_name,ocg->e.m);
 		
 			if (luo != NULL)
 				luo->del(luo);
@@ -1175,11 +1193,12 @@ int main(int argc, char *argv[])
 			int npat;			/* Number of test patches in it8 chart */
 			int nsetel = 0;		/* Number of output set elements */
 			cgats_set_elem *setel;  /* Array of set value elements */
+			unsigned int *idhash; 	/* Array of reference id hashes */
 	
 			icg = new_cgats();			/* Create a CGATS structure */
 			icg->add_other(icg, ""); 	/* Accept any type */
 			if (icg->read_name(icg, datin_name))
-				error("CGATS file '%s' read error : %s",datin_name,icg->err);
+				error("CGATS file '%s' read error : %s",datin_name,icg->e.m);
 	
 			/* ~~ should accept ti2 file and convert RGB to XYZ using    */
 			/*    device cal., to make W/RGB/CMYK ->XYZ reading chart ~~ */
@@ -1326,32 +1345,52 @@ int main(int argc, char *argv[])
 			if ((setel = (cgats_set_elem *)malloc(sizeof(cgats_set_elem) * nsetel)) == NULL)
 				error("Malloc failed!");
 
-			/* Initialise, ready to read out all the values */
+			if ((idhash = (unsigned int *)malloc(sizeof(unsigned int) * npat)) == NULL)
+				error("Malloc failed!");
+
+			/* Setup hash list of reference labels to speed comparisons */
 			for (j = 0; j < npat; j++) {
-				char id[100];				/* Input patch id */
-	
-				/* Normalise labels */
-				fix_it8(id,((char *)icg->t[0].fdata[j][sx]));	/* Copy and fix */
-	
-				/* Search for matching id */
-				for (i = sr->reset(sr); i > 0; i--) {
-					char tod[100];		/* Output patch id */
-					char od[100];		/* Output patch id */
-					double P[4];		/* Robust/true mean values */
-					double sdP[4];		/* Standard deviation */
-					int pixcnt;			/* Pixel count */
+				char id[100];		/* Reference patch id */
 
-					if (tmean)
-						sr->read(sr, tod, NULL, P, sdP, &pixcnt);
-					else
-						sr->read(sr, tod, P, NULL, sdP, &pixcnt);
+				/* Normalise reference labels */
+				fix_it8(id, ((char *)icg->t[0].fdata[j][sx]));	/* Copy and fix */
 
-					if (pixcnt == 0)
-						pnotscan++;
+				idhash[j] = shash(id);
+			}
 
-					fix_it8(od,tod);
+			/* Initialise, ready to read out all the values */
+			for (i = sr->reset(sr); i > 0; i--) {
+				char tod[100];			/* Temp output patch id */
+				char od[100];			/* Output patch id */
+				unsigned int odhash;	/* Chart id hashes */
+				double P[4];			/* Robust/true mean values */
+				double sdP[4];			/* Standard deviation */
+				int pixcnt;				/* Pixel count */
+
+				if (tmean)
+					sr->read(sr, tod, NULL, P, sdP, &pixcnt);
+				else
+					sr->read(sr, tod, P, NULL, sdP, &pixcnt);
+
+				fix_it8(od, tod);
+
+				odhash = shash(od);
 		
-					if (strcmp(id,od) == 0) {
+				if (pixcnt == 0)
+					pnotscan++;
+
+				/* Search for matching id in reference */
+				for (j = 0; j < npat; j++) {
+					char id[100];		/* Reference patch id */
+
+					if (odhash != idhash[j]) {	/* Fast reject */
+						continue;
+					}
+
+					/* Normalise reference labels */
+					fix_it8(id, ((char *)icg->t[0].fdata[j][sx]));	/* Copy and fix */
+	
+					if (strcmp(id, od) == 0) {
 						int k = 0, m;
 						double XYZ[3];
 
@@ -1386,17 +1425,19 @@ int main(int argc, char *argv[])
 
 						break;
 					}
+
+					if (j >= npat && verb >= 1)
+						printf("Warning: Couldn't match field '%s'\n",od);
 				}
-				if (i <= 0 && verb >= 1)
-					printf("Warning: Couldn't match field '%s'\n",id);
 			}
 	
 			if (verb)
 				printf("Writing output values to file '%s'\n",datout_name);
 				
 			if (ocg->write_name(ocg, datout_name))
-				error("Output file '%s' write error : %s",datout_name, ocg->err);
+				error("Output file '%s' write error : %s",datout_name, ocg->e.m);
 	
+			free(idhash);
 			free(setel);
 
 			ocg->del(ocg);		/* Clean up */
@@ -1421,6 +1462,7 @@ int main(int argc, char *argv[])
 
 /* Fix IT8 chart labels */
 void fix_it8(char *o, char *i) {
+	/* Some hacks for it8 */
 	if (strcmp(i,"Dmin")==0) {
 		strcpy(o,"GS00");
 		return;
@@ -1429,6 +1471,7 @@ void fix_it8(char *o, char *i) {
 		strcpy(o,"GS23");
 		return;
 	}
+
 	while (!isdigit(*i) && *i != '\000') 	/* Skip non-numbers */
 		*o++ = *i++; 
 	if (i[0] != '\000' && i[1] == '\000')	/* Single last digit */
@@ -1437,3 +1480,5 @@ void fix_it8(char *o, char *i) {
 }
 
 /********************************************************************************/
+
+
