@@ -346,7 +346,7 @@ int verb, int ddebug) {
 	const char *options[3];
 	char port[50];
 	int portno = 0;		/* Port number allocated */
-	int forcedef = 0;	/* Force default reciever app. */
+	int forcedef = 0;	/* Force default receiver app. */
 
 	if ((p = (chws *)calloc(sizeof(chws), 1)) == NULL) {
 		error("new_chws: calloc failed");
@@ -752,6 +752,7 @@ int native,						/* X0 = use current per channel calibration curve */
 								/* 1X = disable color management cLUT (MadVR) */
 int *noramdac,					/* Return nz if no ramdac access. native is set to X0 */
 int *nocm,						/* Return nz if no CM cLUT access. native is set to 0X */
+double icalmax,					/* Scale instrument calibration test values by this (0.0 .. 1.0) */
 int out_tvenc,					/* 1 = use RGB Video Level encoding */
 int fullscreen,					/* NZ if whole screen should be filled with black */
 int noinitpatch,				/* NZ if no initial test patch should be shown */
@@ -776,6 +777,7 @@ int ddebug						/* >0 to print debug statements to stderr */
 	p->height = height;
 	p->nowin = nowin;
 	p->native = native;
+	p->icalmax = icalmax;
 	p->out_tvenc = out_tvenc;
 	p->fullscreen = fullscreen;
 	p->ddebug = ddebug;
@@ -801,7 +803,7 @@ int ddebug						/* >0 to print debug statements to stderr */
 		*nocm = 1;
 	p->native &= ~2;
 
-	p->rgb[0] = p->rgb[1] = p->rgb[2] = 0.5;	/* Set Grey as the initial test color */
+	p->rgb[0] = p->rgb[1] = p->rgb[2] = 0.5 * icalmax;	/* Set Grey as the initial test color */
 	
 	dispwin_set_default_delays(p);
 
@@ -839,7 +841,7 @@ int ddebug						/* >0 to print debug statements to stderr */
 		return NULL;
 	}
 
-	debugr2((errout,"new_ccwin: return sucessfully\n"));
+	debugr2((errout,"new_ccwin: return successfully\n"));
 
 	return p;
 }
