@@ -101,7 +101,7 @@ colorhug_interp_error(inst *pp, int ec) {
 		case COLORHUG_OK:
 			return "OK";
 		case COLORHUG_UNKNOWN_CMD:
-			return "Unknown connamd";
+			return "Unknown command";
 		case COLORHUG_WRONG_UNLOCK_CODE:
 			return "Wrong unlock code";
 		case COLORHUG_NOT_IMPLEMENTED:
@@ -213,13 +213,13 @@ colorhug_command(colorhug *p,
 
 	a1logd(p->log,8,"colorhug_command: Read %d bytes and %d read\n",xrbytes,rbytes);
 	if (rbytes >= 2) {
-		a1logd(p->log,6,"colorhug_command: recieved cmd '%s' error '%s' args '%s'\n",
+		a1logd(p->log,1,"colorhug_command: received cmd '%s' error '%s' args '%s'\n",
 				inst_desc(buf[1]),
 				colorhug_interp_error((inst *) p, buf[0]),
 				icoms_tohex(buf, rbytes - 2));
 	}
 
-	if (se != 0) {
+	if (se != 0 || buf[0] != COLORHUG_OK) {
 
 		/* deal with command error */
 		if (buf[0] != COLORHUG_OK) {
@@ -815,7 +815,6 @@ colorhug_interp_code(inst *pp, int ec) {
 		case COLORHUG_UNKNOWN_CMD:
 		case COLORHUG_WRONG_UNLOCK_CODE:
 		case COLORHUG_NOT_IMPLEMENTED:
-		case COLORHUG_UNDERFLOW_SENSOR:
 		case COLORHUG_NO_SERIAL:
 		case COLORHUG_WATCHDOG:
 		case COLORHUG_INVALID_ADDRESS:
@@ -823,18 +822,23 @@ colorhug_interp_code(inst *pp, int ec) {
 		case COLORHUG_INVALID_CHECKSUM:
 		case COLORHUG_INVALID_VALUE:
 		case COLORHUG_UNKNOWN_CMD_FOR_BOOTLOADER:
-		case COLORHUG_NO_CALIBRATION:
 		case COLORHUG_OVERFLOW_MULTIPLY:
 		case COLORHUG_OVERFLOW_ADDITION:
 		case COLORHUG_OVERFLOW_SENSOR:
 		case COLORHUG_OVERFLOW_STACK:
-		case COLORHUG_DEVICE_DEACTIVATED:
 		case COLORHUG_INCOMPLETE_REQUEST:
 		case COLORHUG_BAD_WR_LENGTH:
 		case COLORHUG_BAD_RD_LENGTH:
 		case COLORHUG_BAD_RET_CMD:
 		case COLORHUG_BAD_RET_STAT:
 			return inst_protocol_error | ec;
+
+		case COLORHUG_UNDERFLOW_SENSOR:
+			return inst_misread | ec;
+
+		case COLORHUG_DEVICE_DEACTIVATED:
+		case COLORHUG_NO_CALIBRATION:
+			return inst_hardware_fail | ec;
 	}
 	return inst_other_error | ec;
 }
