@@ -2,7 +2,7 @@
 /* Windows NT serial I/O class */
 
 /* 
- * Argyll Color Correction System
+ * Argyll Color Management System
  *
  * Author: Graeme W. Gill
  * Date:   28/9/97
@@ -27,7 +27,7 @@ int serial_get_paths(icompaths *p, icom_type mask) {
 	LONG stat;
 	HKEY sch;		/* Serial coms handle */
 
-	a1logd(p->log, 7, "serial_get_paths: called with mask = %d\n",mask);
+	a1logd(p->log, 7, "serial_get_paths: called with mask = 0x%x\n",mask);
 
 	// (Beware KEY_WOW64_64KEY ?)
 
@@ -168,7 +168,7 @@ static void nt_ser_clearerr(icoms *p) {
 	DWORD errs;
 
 	if (!ClearCommError(p->phandle, &errs,NULL))
-   		error("nt_ser_clearerr: failed, and Clear error failed");
+   		warning("nt_ser_clearerr: failed, and Clear error failed in %s at %d",__FILE__,__LINE__);
 
 	return;
 }
@@ -501,7 +501,7 @@ double tout)
 
 	a1logd(p->log, 8, "\nicoms_ser_write: ep 0x%x, bytes %d, ttop %d, quant %d\n", p->rd_ep, len, ttop, p->rd_qa);
 
-	/* Set the timout value */
+	/* Set the timeout value */
 	tmo.ReadIntervalTimeout = 0;
 	tmo.ReadTotalTimeoutMultiplier = 0;
 	tmo.ReadTotalTimeoutConstant = ttop;
@@ -529,7 +529,7 @@ double tout)
 		if (rv == 0) {
 			DWORD errs;
 			if (!ClearCommError(p->phandle,&errs,NULL))
-				error("icoms_ser_write: failed, and Clear error failed");
+				warning("icoms_ser_write: failed, and Clear error failed in %s at %d",__FILE__,__LINE__);
 			if (errs & CE_BREAK)
 				retrv |= ICOM_BRK; 
 			if (errs & CE_FRAME)
@@ -596,7 +596,7 @@ double tout			/* Time out in seconds */
 
 	a1logd(p->log, 8, "\nicoms_ser_read: bytes %d, ttop %d, ntc %d\n", bsize, ttop, ntc);
 
-	/* Set the timout value */
+	/* Set the timeout value */
 	tmo.ReadIntervalTimeout = 20;			/* small inter character to detect tc */
 	tmo.ReadTotalTimeoutMultiplier = 0;		/* No per byte */
 	tmo.ReadTotalTimeoutConstant = ttop;	/* Just overall total */
@@ -649,7 +649,7 @@ double tout			/* Time out in seconds */
 		if (rv == 0) {
 			DWORD errs;
 			if (!ClearCommError(p->phandle,&errs,NULL))
-				error("icoms_ser_read: failed, and Clear error failed");
+				warning("icoms_ser_read: failed, and Clear error failed in %s at %d",__FILE__,__LINE__);
 			if (errs & CE_BREAK)
 				retrv |= ICOM_BRK; 
 			if (errs & CE_FRAME)
