@@ -38,14 +38,15 @@
 #include <ctype.h>
 #include <string.h>
 #include <time.h>
+#include "numsup.h"
 #ifndef SALONEINSTLIB
 #include "copyright.h"
 #include "aconfig.h"
 #include "rand.h"
 #else
 #include "sa_config.h"
+#include "sa_conv.h"
 #endif /* !SALONEINSTLIB */
-#include "numsup.h"
 #include "cgats.h"
 #include "xspect.h"
 #include "conv.h"
@@ -674,6 +675,7 @@ void *cntx			/* Context for callback */
 
 #ifdef ENABLE_FAST_SERIAL
 	if (itype == instSpecbos1201
+	 || itype == instSpecbos2501
 	 || itype == instSpecbos
 	 || itype == instSpectraval)
 		p = (inst *)new_specbos(icom, itype);
@@ -712,6 +714,8 @@ void *cntx			/* Context for callback */
 		p = (inst *)new_spyd2(icom, itype);
 	else if (itype == instSpyderX)
 		p = (inst *)new_spydX(icom, itype);
+	else if (itype == instSpyderX2)
+		p = (inst *)new_spydX2(icom, itype);
 	else if (itype == instEX1)
 		p = (inst *)new_ex1(icom, itype);
 	if (itype == instHuey)
@@ -1699,6 +1703,7 @@ devType fast_ser_dev_type(
 				/* JETI specbos returns "JETI_SBXXXX", where XXXX is the instrument type, */
 				/* except for the 1201 which returns "SB05" */
 				/* The spectraval 1501 returns JETI_SDCM3 NNNNNNN */
+				/* The 2501 returns "JETI_SCB25X1" */
 		
 				/* Over Bluetooth, we get an erronious string "AT+JSCR\r\n" mixed in our output. */
 				/* This would appear to be from the eBMU Bluetooth adapter AT command set. */
@@ -1729,6 +1734,12 @@ devType fast_ser_dev_type(
 					rv = instSpectraval;
 					break;
 				}
+				/* Is this a JETI specbos 2501 response ? */
+				if (len >= 12 && strncmp(buf, "JETI_SCB25X1", 12) == 0) {
+					a1logd(p->log, 5, "fser_inst_type: found JETI specbos 2501\n");
+					rv = instSpecbos2501;
+					break;
+				}
 			}
 			/* Check for user abort */
 			if (uicallback != NULL) {
