@@ -3,7 +3,7 @@
  /* This supports installing OEM data files */
 
 /* 
- * Argyll Color Correction System
+ * Argyll Color Management System
  *
  * Author: Graeme W. Gill
  * Date:   13/11/2012
@@ -21,6 +21,8 @@
 		Although we have made an allowance for a Spyder 1 PLD pattern,
 		we know nothing about it, or even if it exists...
 
+C:\Program Files (x86)\X-Rite\Devices\i1d3\Calibrations
+
  */
 
 #include <stdio.h>
@@ -68,18 +70,19 @@
 oem_target oemtargs = {
 #ifdef NT
 	{	/* Installed files */
-		{ "/ColorVision/Spyder2express/CVSpyder.dll",    targ_spyd2_pld, file_dllcab },
-		{ "/ColorVision/Spyder2pro/CVSpyder.dll",        targ_spyd2_pld, file_dllcab },
-		{ "/PANTONE COLORVISION/ColorPlus/CVSpyder.dll", targ_spyd2_pld, file_dllcab },
-		{ "/Datacolor/Spyder4Express/dccmtr.dll",        targ_spyd_cal, file_dllcab },
-		{ "/Datacolor/Spyder4Pro/dccmtr.dll",            targ_spyd_cal, file_dllcab },
-		{ "/Datacolor/Spyder4Elite/dccmtr.dll",          targ_spyd_cal, file_dllcab },
-		{ "/Datacolor/Spyder4TV HD/dccmtr.dll",          targ_spyd_cal, file_dllcab },
-		{ "/Datacolor/Spyder5Express/dccmtr.dll",        targ_spyd_cal, file_dllcab },
-		{ "/Datacolor/Spyder5Pro/dccmtr.dll",            targ_spyd_cal, file_dllcab },
-		{ "/Datacolor/Spyder5Elite/dccmtr.dll",          targ_spyd_cal, file_dllcab },
-		{ "/Datacolor/Spyder5TV HD/dccmtr.dll",          targ_spyd_cal, file_dllcab },
-		{ "/X-Rite/Devices/i1d3/Calibrations/*.edr",     targ_i1d3_edr, file_data },
+		{ "/ColorVision/Spyder2express/CVSpyder.dll",            targ_spyd2_pld, file_dllcab },
+		{ "/ColorVision/Spyder2pro/CVSpyder.dll",                targ_spyd2_pld, file_dllcab },
+		{ "/PANTONE COLORVISION/ColorPlus/CVSpyder.dll",         targ_spyd2_pld, file_dllcab },
+		{ "/Datacolor/Spyder4Express/dccmtr.dll",                targ_spyd_cal, file_dllcab },
+		{ "/Datacolor/Spyder4Pro/dccmtr.dll",                    targ_spyd_cal, file_dllcab },
+		{ "/Datacolor/Spyder4Elite/dccmtr.dll",                  targ_spyd_cal, file_dllcab },
+		{ "/Datacolor/Spyder4TV HD/dccmtr.dll",                  targ_spyd_cal, file_dllcab },
+		{ "/Datacolor/Spyder5Express/dccmtr.dll",                targ_spyd_cal, file_dllcab },
+		{ "/Datacolor/Spyder5Pro/dccmtr.dll",                    targ_spyd_cal, file_dllcab },
+		{ "/Datacolor/Spyder5Elite/dccmtr.dll",                  targ_spyd_cal, file_dllcab },
+		{ "/Datacolor/Spyder5TV HD/dccmtr.dll",                  targ_spyd_cal, file_dllcab },
+		{ "/X-Rite/Devices/i1d3/Calibrations/*.edr",             targ_i1d3_edr, file_data },
+		{ "/I-O DATA/i1Profiler for PhotoCrysta/EDRFiles/*.edr", targ_i1d3_edr, file_data },
 		{ NULL }
 	},
 	{	/* Volume names */
@@ -203,8 +206,7 @@ int is_s4cal(xfile *xf);
 int is_inno(xfile *xf);
 int is_cab(xfile *xf);
 static xfile *inno_extract(xfile *xi, char *tfilename, int verb);
-static xfile *ai_extract_cab(xfile **pxf, xfile *xi, char *tname, int verb);
-//static xfile *aifile_extract(xfile **pxf, xfile *xi, char *tname, int verb);
+static xfile *ai_extract_cab(xfile **pxf, xfile *xi, char *key, char *tname, int verb);
 static xfile *msi_extract_cab(xfile **pxf, xfile *xi, char *tname, int verb);
 static xfile *cab_extract(xfile **pxf, xfile *xi, char *text, int verb);
 
@@ -240,7 +242,7 @@ static void list_files(char *s, xfile *xf) {
 /* Return NULL if none found. files is deleted. */
 xfile *oemarch_get_ifiles(xfile *files, int verb) {
 	int i;
-	xfile *ofiles, *nfiles = NULL;	/* Ping pong */
+	xfile *ofiles = NULL, *nfiles = NULL;	/* Ping pong */
 
 #ifdef DEBUG
 	list_files("On entry", files);
@@ -271,11 +273,21 @@ xfile *oemarch_get_ifiles(xfile *files, int verb) {
 		/* Look for files on a CD */
 		xfile *vol;		/* CD volume located */
 
+#ifdef DEBUG
+		printf("Looking for CD files:\n");
+#endif
+
 		if ((vol = locate_volume(verb)) == NULL) {
+#ifdef DEBUG
+			printf("No CD volumes found\n");
+#endif
 			return NULL;
 		}
 
 		if ((files = locate_read_archive(vol, verb)) == NULL) {
+#ifdef DEBUG
+			printf("locate_read_archive failed\n");
+#endif
 			oem_umiso();
 			return NULL;
 		}
@@ -294,6 +306,10 @@ xfile *oemarch_get_ifiles(xfile *files, int verb) {
 	for (i = 0; files[i].name != NULL; i++) {
 		xfile *arch = files + i;
 
+#ifdef DEBUG
+		printf("processing '%s'\n",files[i].name);
+#endif
+
 		/* Preserve & skip non-archives */
 		if (files[i].ftype != file_arch) {
 			new_add_xf(&nfiles, files[i].name, files[i].buf, files[i].len,
@@ -344,7 +360,7 @@ xfile *oemarch_get_ifiles(xfile *files, int verb) {
 			if ((exe = inno_extract(arch, "{tmp}\\XRD Manager.exe", verb)) != NULL) {
 	
 				/* Extract the "disk1.cab" from the AI installer exectutable */
-				if ((ai_extract_cab(&nfiles, exe, "disk1.cab", verb)) != NULL) {
+				if ((ai_extract_cab(&nfiles, exe, ".edr", "disk1.cab", verb)) != NULL) {
 					del_xf(exe);
 					continue;
 				}
@@ -358,15 +374,15 @@ xfile *oemarch_get_ifiles(xfile *files, int verb) {
 				continue;
 
 			/* Extract the "disk1.cab" from the AI installer exectutable */
-			if ((ai_extract_cab(&nfiles, arch, "disk1.cab", verb)) != NULL)
+			if ((ai_extract_cab(&nfiles, arch, ".edr", "disk1.cab", verb)) != NULL)
 				continue;
 #endif
 		}
 		if (verb) printf("Warning: unhandled archive '%s' discarded\n",arch->name);
 	}
-	ofiles = files;		/* Swap to new list */
-	files = nfiles;
 	del_xf(ofiles);
+	ofiles = NULL;		/* Swap to new list */
+	files = nfiles;
 	nfiles = NULL;
 	
 #ifdef DEBUG
@@ -412,9 +428,9 @@ xfile *oemarch_get_ifiles(xfile *files, int verb) {
 		}
 		if (verb) printf("Warning: unhandled dll/cab '%s' discarded\n",dllcab->name);
 	}
-	ofiles = files;		/* Swap to new list */
-	files = nfiles;
 	del_xf(ofiles);
+	ofiles = NULL;		/* Swap to new list */
+	files = nfiles;
 	nfiles = NULL;
 
 #ifdef DEBUG
@@ -427,31 +443,44 @@ xfile *oemarch_get_ifiles(xfile *files, int verb) {
 	/* Process any .edr files - convert to ccss */
 	for (i = 0; files[i].name != NULL; i++) {
 
+#ifdef DEBUG
+		printf(" file '%s' ftype 0x%x ttype 0x%x\n", files[i].name,files[i].ftype,files[i].ttype);
+#endif
+
 		/* Preserve non-edr */
 		if (files[i].ftype != file_data
 		 || (files[i].ttype & targ_i1d3_edr) == 0
 		 || !is_edr(&files[i])
 		) {
+#ifdef DEBUG
+			printf(" preserving '%s'\n", files[i].name);
+#endif
 			new_add_xf(&nfiles, files[i].name, files[i].buf, files[i].len,
 			                                files[i].ftype, files[i].ttype);
 			files[i].buf = NULL;	/* We've taken these */
 			files[i].len = 0;
 			continue;
 		}
+#ifdef DEBUG
+		printf(" converting '%s'\n", files[i].name);
+#endif
+
 		if (edr_convert(&nfiles, files + i, verb) != NULL)
 			continue;
 
 		if (verb) printf("Warning: unhandled edr '%s' discarded\n",files[i].name);
 	}
-	ofiles = files;		/* Swap to new list */
-	files = nfiles;
 	del_xf(ofiles);
+	ofiles = NULL;		/* Swap to new list */
+	files = nfiles;
 	nfiles = NULL;
 
 	/* Mark any files that wern't recognized as unknown */
-	for (i = 0; files[i].name != NULL; i++) {
-		if (files[i].ttype & targ_unknown)
-			files[i].ttype = targ_unknown;
+	if (files != NULL) {
+		for (i = 0; files[i].name != NULL; i++) {
+			if (files[i].ttype & targ_unknown)
+				files[i].ttype = targ_unknown;
+		}
 	}
 
 #ifdef DEBUG
@@ -735,10 +764,23 @@ static xfile *locate_read_archive(xfile *vol, int verb) {
 	return xf;
 }
 
+/* Do a string copy while replacing all '\' characters with '/' */
+static void copyfixdirsep(char *d, char *s) { 
+	for (;;) {
+		*d = *s;
+		if (*s == '\000')
+			break;
+		if (*d == '\\')
+			*d = '/';
+		s++;
+		d++;
+	}
+}
+
 /* Locate and read any OEM install files. */
-/* Return NULL if not found */
+/* Return last file or NULL if not found */
 static xfile *locate_read_oeminstall(xfile **pxf, int verb) {
-	int j;
+	int j, k;
 	char tname[1000], *pf, *ap;
 	xfile *xf = NULL;		/* return value */
 	aglob ag;
@@ -748,11 +790,30 @@ static xfile *locate_read_oeminstall(xfile **pxf, int verb) {
 	tname[0] = '\000';
 
 #ifdef NT
+# if defined(_WIN64)
+	for  (k = 0; k < 2; k++) { 
+		if (k == 0) {
+			/* Where the normal instalation goes */
+			if ((pf = getenv("PROGRAMFILES")) != NULL)
+				copyfixdirsep(tname, pf);
+			else
+				strcpy(tname, "C:/Program Files");
+
+		} else {
+			/* WOW64 installations */
+			/* Where the normal instalation goes */
+			if ((pf = getenv("PROGRAMFILES(x86)")) != NULL)
+				copyfixdirsep(tname, pf);
+			else
+				strcpy(tname, "C:/Program Files (x86)");
+		}
+#else
 	/* Where the normal instalation goes */
 	if ((pf = getenv("PROGRAMFILES")) != NULL)
-		strcpy(tname, pf);
+		copyfixdirsep(tname, pf);
 	else
 		strcpy(tname, "C:/Program Files");
+#endif
 #endif /* NT */
 
 	ap = tname + strlen(tname);
@@ -768,15 +829,24 @@ static xfile *locate_read_oeminstall(xfile **pxf, int verb) {
 
 		for (;;) {
 			char *pp;
+
 			if ((pp = aglob_next(&ag)) == NULL)
 				break;
-			xf = new_add_xf(&xf, pp, NULL, 0, oemtargs.archnames[j].ftype,
-			                                   oemtargs.archnames[j].ttype);
+
+			xf = new_add_xf(pxf, pp, NULL, 0, oemtargs.instpaths[j].ftype,
+			                                  oemtargs.instpaths[j].ttype);
+
 			if (load_xfile(xf, verb))
 				error("Failed to load file '%s'",xf->name);
+
+			if (verb > 1) printf("Loaded '%s'\n",xf->name);
 		}
 		aglob_cleanup(&ag);
 	}
+
+#if defined(NT) && defined(_WIN64)
+	}		/* Next Program Files directory */
+#endif
 	return xf;
 }
 
@@ -784,6 +854,7 @@ static xfile *locate_read_oeminstall(xfile **pxf, int verb) {
 /* A list of files stored in memory. The last entry of the list has name == NULL */
 
 /* return a list with the given number of available entries */
+/* plus one more for the end marker */
 xfile *new_xf(int n) {
 	xfile *l;
 
@@ -794,7 +865,8 @@ xfile *new_xf(int n) {
 }
 
 /* Add an entry to the list. Create the list if it is NULL */
-/* Return point to that entry */
+/* Set end marker. */
+/* Return the pointer to the new entry */
 xfile *add_xf(xfile **l) {
 	int n;
 	xfile *ll;
@@ -808,6 +880,7 @@ xfile *add_xf(xfile **l) {
 
 	if ((*l = (xfile *)realloc(*l, (n+2) * sizeof(xfile))) == NULL)
 		error("new_xf: Failed to realloc xfile structure of %d x %d bytes",(n+2), sizeof(xfile));
+
 	(*l)[n+1].name = NULL;		/* End marker */
 	(*l)[n+1].buf = NULL;
 	(*l)[n+1].len = 0;
@@ -822,6 +895,7 @@ xfile *add_xf(xfile **l) {
 xfile *new_add_xf(xfile **pxf, char *name, unsigned char *buf, unsigned long len,
                                             file_type ftype, targ_type ttype) {
 	xfile *xf;
+
 	xf = add_xf(pxf);
 	if ((xf->name = strdup(name)) == NULL) 
 		error("new_add_xf: strdup failed");
@@ -829,9 +903,18 @@ xfile *new_add_xf(xfile **pxf, char *name, unsigned char *buf, unsigned long len
 	xf->len = len;
 	xf->ftype = ftype;
 	xf->ttype = ttype;
+
 	return xf;
 }
 
+/* Clear this (last) entry on the list so that it becomes the end marker */
+void rm_xf(xfile *xf) {
+	free(xf->name);
+	xf->name = NULL;
+	free(xf->buf);
+	xf->buf = NULL;
+}
+
 /* Free up a whole list */
 void del_xf(xfile *l) {
 	int n;
@@ -949,7 +1032,7 @@ void save_xfile(xfile *xf, char *sname, char *pfx, int verb) {
 	if (fclose(fp))
 		error("Failed to close file '%s' after writing",fname);
 
-	if (verb) printf("Wrote '%s' %ld bytes\n",fname, xf->len);
+	if (verb) printf("Wrote '%s' %" PFSTPREC "d bytes\n",fname, xf->len);
 
 	if (sname == NULL)
 		free(fname);
@@ -1215,7 +1298,7 @@ static xfile *vise_extract(xfile **pxf, xfile *arch, char *tfilename, int verb)
 	vi->dsize = vi->dasize = 0;
 	vi->del(vi);
 
-	if (verb) printf("Returning '%s' length %ld from '%s'\n",xf->name, xf->len, arch[0].name);
+	if (verb) printf("Returning '%s' length %" PFSTPREC "d from '%s'\n",xf->name, xf->len, arch[0].name);
 
 
 	return xf;
@@ -1328,7 +1411,7 @@ static xfile *spyd2pld_extract(xfile **pxf, xfile *dll, int verb) {
 	xf->ftype = file_data;
 	xf->ttype = targ_spyd2_pld;
 
-	if (verb) printf("Returning '%s' length %ld from '%s'\n",xf->name, xf->len, dll->name);
+	if (verb) printf("Returning '%s' length %" PFSTPREC "d from '%s'\n",xf->name, xf->len, dll->name);
 
 	return xf;
 }
@@ -1355,19 +1438,22 @@ int is_s4cal(xfile *xf) {
 static xfile *spyd4cal_extract(xfile **pxf, xfile *dll, int verb) {
 	unsigned char *buf, *caldata;
 	unsigned int size;
-	unsigned int i, j;
+	unsigned int i, j, ii, k;
 	int nocals;
 	unsigned int rfsize;
 	/* First 41 x 8 bytes are the following pattern: */
 	unsigned char cal2vals[8] = { 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x3f };
-	unsigned char cal2evals[7] = { '3', '3', '3', '7', '1', '0', '-' };
+	unsigned char cal2evals[2][7] = {
+		{ '3', '3', '3', '7', '1', '0', '-' },
+		{ 0x88, 0x13, 0x00, 0x00, 0x4a, 0x49, 0x4e }	
+	};
 	xfile *xf = NULL;
 
 	buf = dll->buf;
 	size = dll->len;
 
 	/* Search for start of the calibration data */
-	for(i = 0; i < (size - 41 * 8 - 7) ;i++) {
+	for (i = 0; i < (size - 41 * 8 - 7) ;i++) {
 		if (buf[i] == cal2vals[0]) {
 			for (j = 0; j < (41 * 8); j++) {
 				if (buf[i + j] != cal2vals[j % 8])
@@ -1385,17 +1471,24 @@ static xfile *spyd4cal_extract(xfile **pxf, xfile *dll, int verb) {
 	caldata = buf + i;
 
 	/* Search for end of the calibration data */
-	for(i += (41 * 8); i < (size-7) ;i++) {
-		if (buf[i] == cal2evals[0]) {
-			for (j = 0; j < 7; j++) {
-				if (buf[i + j] != cal2evals[j])
-					break;
+	ii = i + (41 * 8);
+	for (k = 0; k < 2; k++)	{		/* Try each possible end marker */
+
+		for (i = ii; i < (size-7) ;i++) {
+			if (buf[i] == cal2evals[k][0]) {
+				for (j = 0; j < 7; j++) {
+					if (buf[i + j] != cal2evals[k][j])
+						break;
+				}
+				if (j >= 7)
+					break;		/* found string after calibration data */
 			}
-			if (j >= 7)
-				break;		/* found string after calibration data */
+		}
+		if (i < (size-7)) {
+			break;				/* found string */
 		}
 	}
-	if (i >= (size-7)) {
+	if (k >= 2) {
 		if (verb) printf("Failed to locate end of Spyder 4 calibration data in '%s'\n",dll->name);
 		return NULL;
 	}
@@ -1429,7 +1522,7 @@ static xfile *spyd4cal_extract(xfile **pxf, xfile *dll, int verb) {
 	xf->ftype = file_data;
 	xf->ttype = targ_spyd_cal;
 
-	if (verb) printf("Returning '%s' length %ld from '%s'\n",xf->name, xf->len, dll[0].name);
+	if (verb) printf("Returning '%s' length %" PFSTPREC "d from '%s'\n",xf->name, xf->len, dll[0].name);
 
 	return xf;
 }
@@ -1440,7 +1533,7 @@ static xfile *spyd4cal_extract(xfile **pxf, xfile *dll, int verb) {
 static ccss *parse_EDR(unsigned char *buf, unsigned long len, char *name, int verb);
 static ccss *read_EDR_file(char *name, int verb);
 
-/* Do conversion. Return NZ on sucess */
+/* Do conversion. Return NZ on success */
 static xfile *edr_convert(xfile **pxf, xfile *xi, int verb) {
 	xfile *xf = NULL;
 	ccss *c;
@@ -1456,7 +1549,7 @@ static xfile *edr_convert(xfile **pxf, xfile *xi, int verb) {
 		unsigned char *buf;
 		size_t len;
 		if (c->buf_write_ccss(c, &buf, &len)) {
-			error("Failed to create ccss for '%s' error '%s'",xi->name,c->err);
+			error("Failed to create ccss for '%s' error '%s'",xi->name,c->e.m);
 		}
 		/* Convert .edr file name to .ccss */
 	
@@ -1579,29 +1672,32 @@ static ccss *parse_EDR(
 
 	/* We hard code the mapping between the .edr display technology and the */
 	/* ArgyllCMS equivalent. We could in theory figure it out by reading the */
-	/* TechnologyStrings.txt file that comes with the .edr's */
+	/* TechnologyStrings.txt file that comes with the .edr's, but often this */
+	/* is not up to date */
 	{
 		ttmin = 0;
-		ttmax = 22;
+		ttmax = 64;
 		if ((tdtypes = (disptech *)malloc(sizeof(disptech) * (ttmax - ttmin + 2))) == NULL) {
 			if (verb) printf("Malloc failed\n");
 			return NULL;
 		}
+		for (i = 0; i <= (ttmax+1); i++)
+			tdtypes[i] = disptech_unknown;
 
 		tdtypes[0]  = disptech_unknown; /* CMF */
 		tdtypes[1]  = disptech_unknown; /* Custom */
 		tdtypes[2]  = disptech_crt;
 		tdtypes[3]  = disptech_lcd_ccfl_ips;
-		tdtypes[4]  = disptech_lcd_ccfl_vpa;
+		tdtypes[4]  = disptech_lcd_ccfl_pva;
 		tdtypes[5]  = disptech_lcd_ccfl_tft;
 		tdtypes[6]  = disptech_lcd_ccfl_wg_ips;
-		tdtypes[7]  = disptech_lcd_ccfl_wg_vpa;
+		tdtypes[7]  = disptech_lcd_ccfl_wg_pva;
 		tdtypes[8]  = disptech_lcd_ccfl_wg_tft;
 		tdtypes[9]  = disptech_lcd_wled_ips;
-		tdtypes[10] = disptech_lcd_wled_vpa;
+		tdtypes[10] = disptech_lcd_wled_pva;
 		tdtypes[11] = disptech_lcd_wled_tft;
 		tdtypes[12] = disptech_lcd_rgbled_ips;
-		tdtypes[13] = disptech_lcd_rgbled_vpa;
+		tdtypes[13] = disptech_lcd_rgbled_pva;
 		tdtypes[14] = disptech_lcd_rgbled_tft;
 		tdtypes[15] = disptech_oled;
 		tdtypes[16] = disptech_amoled;
@@ -1611,7 +1707,9 @@ static ccss *parse_EDR(
 		tdtypes[10] = disptech_dlp_rgbw;
 		tdtypes[21] = disptech_dlp_rgbcmy;
 		tdtypes[22] = disptech_dlp;
-		tdtypes[23] = disptech_unknown;
+		tdtypes[23] = disptech_lcd_nrgledp_ips;		// PFS_Phosphor_Family
+		tdtypes[24] = disptech_woled;				// FSI_XM55U, LG WOLED 
+		tdtypes[64] = disptech_lcd_gbrledp_ips;		// NEC_64_690E_PA242W GB-R LED-backlight
 	}
 
 	if (len < 600) {
@@ -1739,7 +1837,7 @@ static ccss *parse_EDR(
 		nsamples = buf2int(buf + 0x0010);
 
 		if (nsamples != sp.spec_n) {
-			if (verb) printf("File '%s' set %d number of samles %d doesn't match wavelengths %d\n",name,set,nsamples,sp.spec_n);
+			if (verb) printf("File '%s' set %d number of samples %d doesn't match wavelengths %d\n",name,set,nsamples,sp.spec_n);
 			if (samples != NULL) free(samples);
 			if (tdtypes != NULL) free(tdtypes);
 			return NULL;
@@ -1870,6 +1968,7 @@ static ccss *parse_EDR(
 	}
 
 	if (ttype < ttmin || ttype > ttmax) {
+		if (verb) printf(".edr technology type %d out of range\n",ttype);
 		ttype = ttmax + 1;			/* Set to Unknown */
 	}
 
@@ -2427,7 +2526,7 @@ static xfile *inno_extract(xfile *xi, char *tfilename, int verb) {
 	xf->ftype = file_dllcab;
 	xf->ttype = xi->ttype;
 
-	if (verb) printf("Returning '%s' length %ld from '%s'\n",xf->name,xf->len, xi->name);
+	if (verb) printf("Returning '%s' length %" PFSTPREC "d from '%s'\n",xf->name,xf->len, xi->name);
 
 	return xf;
 }
@@ -2574,7 +2673,7 @@ static xfile *msi_extract_cab(xfile **pxf, xfile *xi, char *tname, int verb) {
 	/* Lookup the .cab size (really 64 bit, but we don't care) */
 	len = buf2uint(xi->buf + i + 8);
 
-	if (verb > 1) printf("'%s' is length %ld\n",tname,len);
+	if (verb > 1) printf("'%s' is length %" PFSTPREC "d\n",tname,len);
 
 	if ((xi->len - i) < len) {
 		if (verb) printf("Not enough room for .cab file in source\n");
@@ -2598,17 +2697,19 @@ static xfile *msi_extract_cab(xfile **pxf, xfile *xi, char *tname, int verb) {
 	xf->ftype = file_dllcab;
 	xf->ttype = xi->ttype;
 
-	if (verb) printf("Extracted '%s' length %ld\n",xf->name,xf->len);
+	if (verb) printf("Extracted '%s' length %" PFSTPREC "d\n",xf->name,xf->len);
 
 	return xf;
 }
 
 /* Extract a .cab file from an "Advanced Installer" file. */
+/* We can't actually identify the .cab file name this way, */
+/* so we can try and pick out the one we want based on its contents (key string). */
 /* It's stored in the file uncompressed and contiguous, but */
 /* with the first 0x200 bytes inverted, so we */
 /* just need to identify where it is and its length. */
 /* Return NULL if not found */
-static xfile *ai_extract_cab(xfile **pxf, xfile *xi, char *tname, int verb) {
+static xfile *ai_extract_cab(xfile **pxf, xfile *xi, char *key, char *tname, int verb) {
 	int i, j, k;
 	xfile *xf = NULL;
 	unsigned long cabo, cabsz;
@@ -2616,63 +2717,89 @@ static xfile *ai_extract_cab(xfile **pxf, xfile *xi, char *tname, int verb) {
 
 	if (verb) printf("Attempting to extract '%s' from '%s'\n",tname,xi->name);
 
-	/* Search for inverted .cab signature */
-	for (i = 0; i < (xi->len - 8 - 4); i++) {
-		if (xi->buf[i + 0] == 0xb2
-		 && xi->buf[i + 1] == 0xac
-		 && xi->buf[i + 2] == 0xbc
-		 && xi->buf[i + 3] == 0xb9
-		 && xi->buf[i + 4] == 0xff
-		 && xi->buf[i + 5] == 0xff
-		 && xi->buf[i + 6] == 0xff
-		 && xi->buf[i + 7] == 0xff) {
-			if (verb > 1) printf("Found inverted .cab sig at 0x%x\n",i);
-			break;
+	/* Until we find a .cab with key, or give up */
+	for (i = 0;;i += 8) {
+
+		/* Search for inverted .cab signature */
+		for (; i < (xi->len - 8 - 4); i++) {
+			if (xi->buf[i + 0] == 0xb2
+			 && xi->buf[i + 1] == 0xac
+			 && xi->buf[i + 2] == 0xbc
+			 && xi->buf[i + 3] == 0xb9
+			 && xi->buf[i + 4] == 0xff
+			 && xi->buf[i + 5] == 0xff
+			 && xi->buf[i + 6] == 0xff
+			 && xi->buf[i + 7] == 0xff) {
+				if (verb > 1) printf("Found inverted .cab sig at 0x%x\n",i);
+				break;
+			}
+		}
+		if (i > (xi->len - 8 - 4)) {
+			if (verb) printf(".cab sig not found\n");
+			return NULL;
 		}
-	}
-	if (i > (xi->len - 8 - 4)) {
-		if (verb) printf(".cab sig not found\n");
-		return NULL;
-	}
 
-	/* Lookup the .cab size (really 64 bit, but we don't care) */
-	len = ibuf2uint(xi->buf + i + 8);
+		/* Lookup the .cab size (really 64 bit, but we don't care) */
+		len = ibuf2uint(xi->buf + i + 8);
 
-	if (verb > 1) printf("'%s' is length %ld\n",tname,len);
+		if (verb > 1) printf("'%s' is length %" PFSTPREC "d\n",tname,len);
 
-	if ((xi->len - i) < len) {
-		if (verb) printf("Not enough room for .cab file in source\n");
-		return NULL;
-	}  
+		if ((xi->len - i) < len) {
+			if (verb) printf("Not enough room for .cab file in source\n");
+			return NULL;
+		}  
 
-	xf = add_xf(pxf);
-	xf->len = len;
+		xf = add_xf(pxf);
+		xf->len = len;
 
-	if ((xf->buf = malloc(xf->len)) == NULL) {
-		fprintf(stderr,"maloc of .cab buffer failed\n");
-		exit(-1);
-	}
-	memmove(xf->buf, xi->buf + i ,xf->len);
+		if ((xf->buf = malloc(xf->len)) == NULL) {
+			fprintf(stderr,"maloc of .cab buffer failed\n");
+			exit(-1);
+		}
+		memmove(xf->buf, xi->buf + i ,xf->len);
 
-	/* Restor first 0x200 bytes */
-	for (i = 0; i < 0x200 && i < xf->len; i++) {
-		xf->buf[i] = ~xf->buf[i];
-	}
+		/* Restore first 0x200 bytes */
+		for (j = 0; j < 0x200 && j < xf->len; j++) {
+			xf->buf[j] = ~xf->buf[j];
+		}
 
-	if ((xf->name = strdup(tname)) == NULL) {
-		fprintf(stderr,"maloc of .cab name failed\n");
-		exit(-1);
-	}
+		if ((xf->name = strdup(tname)) == NULL) {
+			fprintf(stderr,"maloc of .cab name failed\n");
+			exit(-1);
+		}
 
-	xf->ftype = file_dllcab;
-	xf->ttype = xi->ttype;
+		xf->ftype = file_dllcab;
+		xf->ttype = xi->ttype;
 
-	if (verb) printf("Extracted '%s' length %ld\n",xf->name,xf->len);
+		if (verb) printf("Extracted .cab '%s' length %" PFSTPREC "d\n",xf->name,xf->len);
 
 //	/* Save diagnostic file */
 //	save_xfile(xf, "temp.cab", NULL, verb);
 
-	return xf;
+		/* If we are givem a key string, check it is located within the buffer */
+		if (key != NULL) {
+			int klen = strlen(key); 
+
+			/* Look for the key string in the buffer */
+			for (j = 0; j < (xf->len -klen); j++) {
+				if (xf->buf[j] == key[0]) {
+					if (strncmp((char *)&xf->buf[j], key, klen) == 0)
+						break;
+				}
+			}
+			if (j >= (xf->len -klen)) {
+				if (verb) printf("Failed to find key '%s' in '%s'\n",key,xf->name);
+				rm_xf(xf);		/* Remove this last entry */
+				xf = NULL;
+			} else {
+				if (verb) printf("Found key '%s' in '%s' at %d\n",key,xf->name, j);
+				if (verb) printf("~~ found '%s'\n",&xf->buf[j]);
+			}
+		}
+		if (xf != NULL)
+			return xf;
+	}
+	return NULL;
 }
 
 
@@ -2994,10 +3121,11 @@ static xfile *cab_extract(xfile **pxf, xfile *xi, char *text, int verb) {
 	}
 
 	if (flags & 4) {		/* If researved fields */
+		fprintf(stderr,"'%s' has reserved fields\n",xi->name);
 		// cbCFHeader, cbCFFolder, and cbCFData are present.
 		headerres = buf2short(buf + 0x24);
 		folderres = buf[0x26];
-		datares = buf[0x27];
+		datares   = buf[0x27];
 
 		hextra = 4 + headerres;
 	}
@@ -3018,7 +3146,8 @@ static xfile *cab_extract(xfile **pxf, xfile *xi, char *text, int verb) {
 		unsigned long fsize;		/* Uncompressed size */
 		unsigned long foff;
 		short ffix;
-		char fname[95];
+		char fname[257];
+		int mxnl = 256, rem;
 		
 		if (off > (len - 80)) {
 			fprintf(stderr,"'%s' too short for directory\n",xi->name);
@@ -3029,8 +3158,11 @@ static xfile *cab_extract(xfile **pxf, xfile *xi, char *text, int verb) {
 		foff  = buf2uint(buf + off + 0x04);
 		ffix  = buf2short(buf + off + 0x08);
 
-		strncpy(fname, (char *)buf + off + 0x10, 94);
-		fname[94] = '\000';
+		rem = len - off;		/* Remaining length in buffer */
+		if (rem < mxnl)
+			mxnl = rem;
+		strncpy(fname, (char *)buf + off + 0x10, mxnl);
+		fname[256] = '\000';
 
 		if (verb > 1) printf("file %d is '%s' at 0x%lx length %ld\n",k,fname, foff,fsize);
 
