@@ -413,7 +413,7 @@ spydX_measSettup(
 
 	a1logd(p->log, 3, "spydX_measSettup got s1 = %d\n",s1);
 	a1logd(p->log, 3, "  s2 = %d %d %d %d\n", s2[0], s2[1], s2[2], s2[3]);
-	a1logd(p->log, 3, "  s2 = %d %d %d %d\n", s3[0], s3[1], s3[2], s3[3]);
+	a1logd(p->log, 3, "  s3 = %d %d %d %d\n", s3[0], s3[1], s3[2], s3[3]);
 
 	return rv;
 }
@@ -485,7 +485,7 @@ static inst_code
 spydX_AmbMeasure(
 	spydX *p,
 	int raw[4],			/* Return four ambient values (last two same as ap[] ?) */
-	int ap[2]			/* Parameters, integration time,  gain control bits */
+	int ap[2]			/* Parameters, integration time, gain control bits */
 ) {
 	int i;
 	ORD8 send[0x2];
@@ -568,7 +568,7 @@ spydX_GetReading(
 /* NOTE :- the ambient sensor seem to be an AMS TSL25721. */
 /* It has two sensors, one wide band and the other infra-red, */
 /* the idea being to subtract them to get a rough human response. */
-/* The reading is 16 bits, with 2 bits of gain and 8 bits of integration time conrtol */
+/* The reading is 16 bits, with 2 bits of gain and 8 bits of integration time control */
 static inst_code
 spydX_GetAmbientReading(
 	spydX *p,
@@ -1008,7 +1008,7 @@ spydX_interp_error(inst *pp, int ec) {
 		case SPYDX_COMS_FAIL:
 			return "Communications failure";
 		case SPYDX_UNKNOWN_MODEL:
-			return "Not a Spyder 2, 3, 4 or 5";
+			return "Not a Spyder X";
 		case SPYDX_DATA_PARSE_ERROR:
 			return "Data from i1 Display didn't parse as expected";
 		case SPYDX_INT_CAL_SAVE:
