@@ -411,6 +411,10 @@ char **pnames		/* List of process names to try and kill before opening */
 			a1logd(p->log, 6, "usb_open_port: SetConfiguration %d OK\n",config);
 		}
 
+		/* For some devices (Spyder 3/4 ?) on some versions of OS X (Ventura ?), */
+		/* we seem to need to let the device recover from the set configuration. */
+		msec_sleep(50);
+
 		/* Get interfaces */
 		{
 			int i, j;
@@ -501,7 +505,7 @@ char **pnames		/* List of process names to try and kill before opening */
 					p->EPINFO(ad).addr = ad;
 					p->EPINFO(ad).packetsize = maxPacketSize;
 					p->EPINFO(ad).type = transferType & IUSB_ENDPOINT_TYPE_MASK;
-					p->EPINFO(ad).interface = i;
+					p->EPINFO(ad).ifaceno = i;
 					p->EPINFO(ad).pipe = j+1;
 					a1logd(p->log, 6, "set ep ad 0x%x packetsize %d type %d, if %d, pipe %d\n",ad,maxPacketSize,transferType & IUSB_ENDPOINT_TYPE_MASK,i,j);
 				}
@@ -583,7 +587,7 @@ static int icoms_usb_transaction(
 	usbio_req req;
 	IOReturn result;
 	CFRunLoopSourceRef cfsource;	/* Device event sources */
-	int iix = p->EPINFO(endpoint).interface;
+	int iix = p->EPINFO(endpoint).ifaceno;
 	UInt8 pno = (UInt8)p->EPINFO(endpoint).pipe;
 
 	in_usb_rw++;
@@ -804,7 +808,7 @@ int icoms_usb_resetep(
 	int ep					/* End point address */
 ) {
 	int reqrv = ICOM_OK;
-	int iix = p->EPINFO(ep).interface;
+	int iix = p->EPINFO(ep).ifaceno;
 	UInt8 pno = (UInt8)p->EPINFO(ep).pipe;
 	IOReturn rv;
 
@@ -823,7 +827,7 @@ int icoms_usb_clearhalt(
 	int ep					/* End point address */
 ) {
 	int reqrv = ICOM_OK;
-	int iix = p->EPINFO(ep).interface;
+	int iix = p->EPINFO(ep).ifaceno;
 	UInt8 pno = (UInt8)p->EPINFO(ep).pipe;
 	IOReturn rv;
 	int irv;
