@@ -59,8 +59,6 @@
 
 /* Description:
 
-   >> THIS NEEDS REVISION <<
-
    Nearly all current Color correction systems generate test charts (or
    device characterisation target charts) by laying out a regular rectangular
    grid of test points in device space (Targen will do this if you feed it a non-zero
@@ -82,20 +80,13 @@
    process, the resulting points are distributed without evident
    patterns.
 
-#ifdef NEVER
-   For higher dimensional spaces, where the aim is to create a
-   more aproximate device profile, I've used a "perfect simplex
-   latice" generator to lay out perfectly packed sample points
-   in perceptual space. The latice spacing is sized by an
-   iterative search to (hopefully) create the right number of
-   test points.
-#else
    For higher dimensional spaces, where the aim is to create a
    more aproximate device profile, I've used an "incremental far
    point" point generator, that for each added point, locates
    the device values that result in a percetual value farthest
    from any existing points in the test set.
-#endif
+
+   Other algorithms for point generation are available too.
 
    Another issue with laying test points out in regular grids, is
    that this means that the device response is poorly sampled
@@ -119,7 +110,6 @@
 #define EMPH_NEUTRAL	/* Emphasise neutral axis, like CIE94 does */
 #define NEMPH_DEFAULT 0.5	/* Default neutral axis emphasis == 2 x CIE94 */
 #define XPOW_DEFAULT 1.0	/* Default extra device power value = none */
-#define DEMPH_DEFAULT 1.0	/* Default dark region emphasis == none */
 #define DEFANGLE 0.3333	/* For simdlat and simplat */
 #define SIMDLAT_TYPE SIMDLAT_BCC	/* Simdlat geometry type */
 #define MATCH_TOLL 1e-4	/* Tollerance of device value to consider a patch a duplicate */
@@ -129,17 +119,13 @@
 #define DISPLAY_FALL_TIME DISPTECH_WORST_FALL		/* Assumed fall time to 90% of target level */
 #define DISPLAY_SETTLE_AIM 0.1		/* Aim for 0.2 Delta E */
 
-#ifdef NEVER	/* Old delay time code */
-#define DISPLAY_SETTLE_AIM2 0.01		/* Aim for 1% of true level */
-#define DISPLAY_ABS_AIM2 0.0001		/* Aim for .01% of true absolute level */
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
 #include <string.h>
 #include <sys/types.h>
 #include <time.h>
+#include <stdarg.h>
 #include "copyright.h"
 #include "aconfig.h"
 #include "numlib.h"
@@ -158,8 +144,6 @@
 #include "prand.h"
 #include "ui.h"
 
-#include <stdarg.h>
-
 #define min2(a,b) ((a) < (b) ? (a) : (b))
 #define min3(a,b,c)  (min2((a), min2((b),(c))))
 #define max2(a,b) ((a) > (b) ? (a) : (b))
@@ -168,6 +152,15 @@
 /* 32 bit pseudo random sequencer */
 #define PSRAND32(S) (((S) & 0x80000000) ? (((S) << 1) ^ 0xa398655d) : ((S) << 1))
 
+/* ---------------------------- */
+
+static double spow(double v, double p) {
+	if (v < 0.0)
+		return -pow(-v, p);
+	else
+		return pow(v, p);
+}   
+
 /* ---------------------------- */
 /* The perception function data */
 /* (Used for test point distribution) */
@@ -175,7 +168,7 @@ struct _pcpt {
 /* public: */
 	void (*del)(struct _pcpt *s);	/* We're done with it */
 
-	int (*is_specific)(struct _pcpt *s);	/* Is a specific model, not defaulte */
+	int (*is_specific)(struct _pcpt *s);	/* Is a specific model, not default */
 
 	/* Conversions */
 	void (*dev_to_perc)(struct _pcpt *s, double *out, double *in);	/* N-chan Perceptual */
@@ -193,7 +186,8 @@ struct _pcpt {
 
 	/* Tuning parameters */
 	double nemph;		/* neutral emphasis, 0.0 - 1.0. Default 0.35 for == CIE94 */
-	double idemph;		/* inv. of dark emphasis, 1.0 - 4.0. Default 1.0 == none */
+	double idemph;		/* inv. of dark emphasis, 1.0 - 0.25. Default 1.0 == none */
+						/* 1.0 - 4.0 for light emphasis */
 	double ixpow;		/* inv. extra power Default 1.0 == none */
 
 	/* ICC profile based */
@@ -208,7 +202,7 @@ struct _pcpt {
 	/* Xcolorants model based */
 	icxColorantLu *clu;	/* Device -> CIE */
 
-	rspl *nlin[MXTD - 3];	/* Perceptual linearisation for other chanels */
+	rspl *nlin[MXTD - 3];	/* Perceptual linearisation for channels beyond the third, i.e. K */
 	int e;					/* Chanel being set */
 
 	/* Reverse lookup support */
@@ -281,11 +275,11 @@ pcpt_to_rLab(pcpt *s, double *out, double *in) {
 
 /* Perceptual conversion function */
 /* Internal device values 0.0 - 1.0 are converted into perceptually uniform 0.0 - 100.0 */
-/* This is used by optimal spread functions ? */
+/* This is used by optimal spread functions */
 static void
 pcpt_to_nLab(pcpt *s, double *out, double *in) {
 	int e;
-	double inv[MXTD];
+	double inv[MXTD];		/* Input value after applying extra power */
 
 	if (s->xmask == s->nmask) {
 		for (e = 0; e < s->di; e++)
@@ -323,18 +317,17 @@ pcpt_to_nLab(pcpt *s, double *out, double *in) {
 		}
 #endif
 
-		/* Dark emphasis */
+		/* Dark/Light emphasis */
 		/* This doesn't actually match how demph is applied to device values... */
-		if (s->idemph < 1.0) {
-			double vv = lab[0];
-			lab[0] = 100.0 * pow(lab[0]/100.0, s->idemph);
+		if (s->idemph != 1.0) {
+			lab[0] = 100.0 * spow(lab[0]/100.0, s->idemph);
 		}
 
 		/* Copy Lab values to output */
 		for (e = 0; e < (s->di < 3 ? s->di : 3); e++)
 			out[e] = lab[e];
 
-		/* Lookup perceptual linearised auxiliary values */
+		/* Lookup perceptual linearised auxiliary values (channels beyond 3, i.e. K) */
 		for (e = 0; e < (s->di-3); e++) {
 			co cc;
 			cc.p[0] = inv[3 + e];
@@ -343,8 +336,7 @@ pcpt_to_nLab(pcpt *s, double *out, double *in) {
 		}
 
 	} else {
-		/* Default linear in Device space */
-
+		/* If we have no conversion, default to linear in Device space */
 		for (e = 0; e < s->di; e++)
 			out[e] = 100.0 * inv[e];
 			if (e == 1 || e == 2)
@@ -577,7 +569,7 @@ pcpt_rLab_to_dev(pcpt *s, double *out, double *in) {
 //printf("~1 returning device values %f %f %f\n",out[0],out[1],out[2]);
 }
 
-/* Callback to setup s->nlin[e] mapping */
+/* Callback to setup s->nlin[e] extra channel (i.e. K) mapping */
 static void set_nlin(void *cbntx, double *out, double *in) {
 	pcpt *s = (pcpt *)cbntx;	/* Object we're setting up from */
 	int e, di = s->di;
@@ -605,8 +597,13 @@ static void set_nlin(void *cbntx, double *out, double *in) {
 	} else {
 		lab[0] = 100.0 * in[0];
 	}
+	if (s->idemph != 1.0) {
+		double vv = lab[0];
+		lab[0] = 100.0 * spow(lab[0]/100.0, s->idemph);
+	}
 
 	/* ~~~ should we make this delta lab along locus, rather than L value ??? */
+
 	out[0] = lab[0];
 }
 
@@ -653,6 +650,7 @@ double *ilimit,			/* ink sum limit (scale 1.0) input and return, -1 if default *
 double *uilimit,		/* underlying ink sum limit (scale 1.0) input and return, -1 if default */
 double nemph,			/* Neutral emphasis, 0.0 - 1.0. < 0.0 for default == CIE94 */
 double demph,			/* Dark emphasis, 1.0 - 4.0. < 0.0 for default == none */
+double lemph,			/* Light emphasis, 1.0 - 4.0. < 0.0 for default == none */
 double xpow				/* Extra device power, default = none */
 ) {
 	int e;
@@ -682,9 +680,13 @@ double xpow				/* Extra device power, default = none */
 	s->nemph = nemph;
 
 	if (demph < 0.0)
-		demph = DEMPH_DEFAULT;
+		demph = 1.0;
 	s->idemph = 1.0/demph;
 
+	if (lemph < 0.0)
+		lemph = 1.0;
+	s->idemph *= lemph;
+
 	if (xpow < 0.0)
 		xpow = XPOW_DEFAULT;
 	s->ixpow = 1.0/xpow;
@@ -836,6 +838,16 @@ double xpow				/* Extra device power, default = none */
 
 /* ------------------------------------ */
 
+/*
+
+  Flags used:
+
+         ABCDEFGHIJKLMNOPQRSTUVWXYZ
+  upper  .. . .. .   ... .. .....   
+  lower  ....... .  ... ..... ..    
+
+*/
+
 void
 usage(int level, char *diag, ...) {
 	int i;
@@ -894,11 +906,12 @@ usage(int level, char *diag, ...) {
 /*	fprintf(stderr,"  -A pPERCWGHT    Device (0.0) ... Perceptual (1.0) weighting\n"); */
 /*	fprintf(stderr,"  -A cCURVEWGHT   Curvature weighting  0.0 = none ... "); */
 	fprintf(stderr," -l ilimit        Total ink limit in %% (default = none)\n");
+	fprintf(stderr," -T ilimit        Text and space total ink limit in %% (default = same as -l)\n");
 	fprintf(stderr," -p power         Optional power-like value applied to all device values.\n");
 	fprintf(stderr," -c profile       Optional device ICC or MPP pre-conditioning profile filename\n");
 	fprintf(stderr,"                  (Use \"none\" to turn off any conditioning)\n");
 	fprintf(stderr," -N emphasis      Degree of neutral axis patch concentration 0.0-1.0 (default %.2f)\n",NEMPH_DEFAULT);
-	fprintf(stderr," -V emphasis      Degree of dark region patch concentration 1.0-4.0 (default %.2f = none)\n",DEMPH_DEFAULT);
+	fprintf(stderr," -V emphasis      Degree of dark region patch concentration 1.0-4.0 (default %.2f = none)\n",1.0);
 	fprintf(stderr," -F L,a,b,rad     Filter out samples outside Lab sphere.\n");
 	fprintf(stderr," -O               Don't re-order display RGB patches for minimum delay\n");
 	fprintf(stderr," -U               Don't filter out duplicate patches\n");
@@ -966,8 +979,11 @@ int main(int argc, char *argv[]) {
 	double curv_wght = 0.0;	/* Curvature weighting */
 	double ilimit = -1.0;	/* Ink limit (scale 1.0) (default none) */
 	double uilimit = -1.0;	/* Underlying (pre-calibration, scale 1.0) ink limit */
+	double tilimit = -1.0;	/* Text and spacer ink limit (scale 1.0) (default none) */
+	double utilimit = -1.0;	/* Text and spacer ink limit (pre-calibration, scale 1.0) */
 	double nemph = NEMPH_DEFAULT;
-	double demph = DEMPH_DEFAULT;
+	double demph = 1.0;		/* Dark emphasis. Default = none */
+	double lemph = 1.0;		/* Light emphasis (inverse of demph). Default = none */
 	int dontdedupe = 0;		/* Don't filter duplicate samples */
 	int dontreorder = 0;	/* Don't re-order RGB display patches for min delay */
 	int filter = 0;			/* Filter values outside given sphere */
@@ -984,10 +1000,12 @@ int main(int argc, char *argv[]) {
 	cgats *pp;				/* cgats structure */
 	long stime,ttime;
 	pcpt *pdata;			/* Space linearisation callback struct */
+	pcpt *tpdata;			/* Text and spacer Space linearisation callback struct */
 	fxpos *fxlist = NULL;	/* Fixed point list for full spread */
 	int fxlist_a = 0;		/* Fixed point list allocation */
 	int fxno = 0;			/* The number of fixed points */
 
+
 #ifdef NUMSUP_H
 	error_program = "targen";
 #endif
@@ -998,7 +1016,7 @@ int main(int argc, char *argv[]) {
 
 	/* Process the arguments */
 	mfa = 1;        /* Minimum final arguments */
-	for(fa = 1;fa < argc;fa++) {
+	for (fa = 1;fa < argc;fa++) {
 		nfa = fa;					/* skip to nfa if next argument is used */
 		if (argv[fa][0] == '-') {	/* Look for any flags */
 			char *na = NULL;		/* next argument after flag, null if none */
@@ -1217,8 +1235,20 @@ int main(int argc, char *argv[]) {
 			else if (argv[fa][1] == 'l') {
 				double tt;
 				if (na == NULL) usage(0,"Expect argument after -l");
-				if ((tt = atof(na)) > 0.0)
+				if ((tt = atof(na)) > 0.0) {
 					uilimit = ilimit = 0.01 * tt;
+					if (tilimit < 0.0)
+						utilimit = tilimit = uilimit; 
+				}
+				fa = nfa;
+			}
+
+			/* Text and space ink limit percentage */
+			else if (argv[fa][1] == 'T') {
+				double tt;
+				if (na == NULL) usage(0,"Expect argument after -l");
+				if ((tt = atof(na)) > 0.0)
+					utilimit = tilimit = 0.01 * tt;
 				fa = nfa;
 			}
 
@@ -1299,6 +1329,7 @@ int main(int argc, char *argv[]) {
 	strncpy(wlname,argv[fa],MAXNAMEL-5); wlname[MAXNAMEL-5] = '\000';
 	strcat(wlname,"l");
 
+
 	/* Set default colorant combination as CMYK */
 	if (xmask == 0)
 		xmask = ICX_CMYK;
@@ -1360,166 +1391,191 @@ int main(int argc, char *argv[]) {
 			if (ssteps == 0 && fsteps == 0 && msteps == 0 && bsteps == 0
 			 && gsteps == 0 && nsteps == 0)
 				error ("Must have some single or multi dimensional RGB or CMY steps");
-		} else {
-			if (ssteps == 0 && fsteps == 0 && msteps == 0 && bsteps == 0
-			    && gsteps == 0 && nsteps == 0)
-				error ("Must have some single or multi dimensional steps");
-		}
-
-		/* Deal with ICC, MPP or fallback profile */
-		if ((pdata = new_pcpt(pname, xmask, nmask, &ilimit, &uilimit, nemph, demph, xpow)) == NULL) {
-			error("Perceptual lookup object creation failed");
-		}
-
-		/* Set default adapation level */
-		if (dadapt < -1.5) {		/* Not set by user */
-			if (pname[0] != '\000')
-				dadapt = 1.0;
-			else
-				dadapt = 0.1;
-		}
-
-		if (verb) {
-			printf("%s test chart\n",ident);
-
-			if (esteps > 0)
-				printf("White patches = %d\n",esteps);
-			if (Bsteps > 0)
-				printf("Black patches = %d\n",Bsteps);
-			if (ssteps > 0)
-				printf("Single channel steps = %d\n",ssteps);
-			if (gsteps > 0)
-				printf("Composite Grey steps = %d\n",gsteps);
-			if (nsteps > 0)
-				printf("Neutral steps = %d\n",nsteps);
-			if (fsteps > 0)
-				printf("Full spread patches = %d\n",fsteps);
-			if (msteps > 0) {
-				if (msurf)
-					printf("Multi-dimention cube surface steps = %d\n",msteps);
-				else
-					printf("Multi-dimention cube steps = %d\n",msteps);
-			}
-			if (bsteps > 0)
-				printf("Multi-dimention body centered cube steps = %d\n",bsteps);
-			if (ilimit >= 0.0)
-				printf("Ink limit = %.1f%% (underlying %.1f%%)\n",ilimit * 100.0, uilimit * 100.0);
-			if (filter) {
-				printf("Filtering out samples outside sphere at %f %f %f radius %f\n",
-						filt[0], filt[1], filt[2], filt[3]);
-			}
-		}
-		pp = new_cgats();	/* Create a CGATS structure */
-		pp->add_other(pp, "CTI1"); 	/* our special type is Calibration Target Information 1 */
-
-		pp->add_table(pp, tt_other, 0);	/* Add the first table for target points */
-		pp->add_table(pp, tt_other, 0);	/* Add the second table for density pre-defined device values */
-		pp->add_table(pp, tt_other, 0);	/* Add the second table for device pre-defined device values */
-		pp->add_kword(pp, 0, "DESCRIPTOR", "Argyll Calibration Target chart information 1",NULL);
-		pp->add_kword(pp, 1, "DESCRIPTOR", "Argyll Calibration Target chart information 1",NULL);
-		pp->add_kword(pp, 2, "DESCRIPTOR", "Argyll Calibration Target chart information 1",NULL);
-		pp->add_kword(pp, 0, "ORIGINATOR", "Argyll targen", NULL);
-		pp->add_kword(pp, 1, "ORIGINATOR", "Argyll targen", NULL);
-		pp->add_kword(pp, 2, "ORIGINATOR", "Argyll targen", NULL);
-		atm[strlen(atm)-1] = '\000';	/* Remove \n from end */
-		pp->add_kword(pp, 0, "CREATED",atm, NULL);
-
-		/* Make available the aproximate white point to allow relative */
-		/* interpretation of the aproximate XYZ values */
-		{
-			int e;
-			double val[MXTD], XYZ[3];
-
-			/* Setup device white */
-			if (nmask & ICX_ADDITIVE)
-				for (e = 0; e < di; e++)
-					val[e] = 1.0;
-			else
-				for (e = 0; e < di; e++)
-					val[e] = 0.0;
-			pdata->dev_to_XYZ(pdata, XYZ, val);		/* Lookup white XYZ */
-
-			sprintf(buf,"%f %f %f", 100.0  * XYZ[0], 100.0 * XYZ[1], 100.0 * XYZ[2]);
-			pp->add_kword(pp, 0, "APPROX_WHITE_POINT", buf, NULL);
-		}
-
-		pp->add_field(pp, 0, "SAMPLE_ID", cs_t);
-		pp->add_field(pp, 1, "INDEX", i_t);			/* Index no. 0..7 in second table */
-		pp->add_field(pp, 2, "INDEX", i_t);			/* Index no. 0..7 in third table */
-
-		/* Setup CGATS fields */
-		{
-			int j;
-			char c_ilimit[20];
-			char *bident = icx_inkmask2char(xmask, 0); 
-
-			for (j = 0; j < di; j++) {
-				int imask;
-				char fname[100];
-
-				imask = icx_index2ink(xmask, j);
-				sprintf(fname,"%s_%s",nmask == ICX_W || nmask == ICX_K ? "GRAY" : bident,
-									  icx_ink2char(imask));
-
-				pp->add_field(pp, 0, fname, r_t);
-				pp->add_field(pp, 1, fname, r_t);
-				pp->add_field(pp, 2, fname, r_t);
-			}
-
-			pp->add_kword(pp, 0, "COLOR_REP", ident, NULL);
-
-			if (ilimit >= 0.0) {
-				sprintf(c_ilimit,"%5.1f",ilimit * 100.0);
-				pp->add_kword(pp, 0, "TOTAL_INK_LIMIT", c_ilimit, NULL);
-			}
-			free(bident);
-		}
-
-		/* ilimit is assumed to be in a valid range from here on */
-		if (ilimit < 0.0) {
-			uilimit = ilimit = di;	/* default is no limit */
-		}
-
-		/* Add expected XYZ values to aid previews, scan recognition & strip recognition */
-		pp->add_field(pp, 0, "XYZ_X", r_t);
-		pp->add_field(pp, 0, "XYZ_Y", r_t);
-		pp->add_field(pp, 0, "XYZ_Z", r_t);
-		pp->add_field(pp, 1, "XYZ_X", r_t);
-		pp->add_field(pp, 1, "XYZ_Y", r_t);
-		pp->add_field(pp, 1, "XYZ_Z", r_t);
-		pp->add_field(pp, 2, "XYZ_X", r_t);
-		pp->add_field(pp, 2, "XYZ_Y", r_t);
-		pp->add_field(pp, 2, "XYZ_Z", r_t);
-
-		/* Note if the expected values are expected to be accurate */
-		if (pdata->is_specific(pdata))
-			pp->add_kword(pp, 0, "ACCURATE_EXPECTED_VALUES", "true", NULL);
-
-		if (xpow != 1.0) {
-			sprintf(buf,"%f",xpow);
-			pp->add_kword(pp, 0, "EXTRA_DEV_POW",buf, NULL);
-		}
-
-		if (demph > 1.0) {
-			sprintf(buf,"%f",demph);
-			pp->add_kword(pp, 0, "DARK_REGION_EMPHASIS",buf, NULL);
-		}
-
-		/* Only use optimsed full spread if <= 4 dimensions, else use ifarp */
-		if (di > 4 
-		 && userand == 0		/* Not other high D useful method */
-		 && useqrand == 0
-		 && usedsim == 0
-		 && usepsim == 0)
-			uselat = 1;
-
-		/* Allocate space to record fixed steps */
-		{
-			fxlist_a = 4;
-			if ((fxlist = (fxpos *)malloc(sizeof(fxpos) * fxlist_a)) == NULL)
-			error ("Failed to malloc fxlist");
+	} else {
+		if (ssteps == 0 && fsteps == 0 && msteps == 0 && bsteps == 0
+		    && gsteps == 0 && nsteps == 0)
+			error ("Must have some single or multi dimensional steps");
 	}
 
+	/* Set default adapation level */
+	if (dadapt < -1.5) {		/* Not set by user */
+		if (pname[0] != '\000')
+			dadapt = 1.0;
+		else
+			dadapt = 0.1;
+	}
+
+	/* Counteract natural dark shift of patches if auxiliary black is used */
+	/* (BUT fully copensate only if adaptation is high !) */
+	if ((di > 3 && xmask & ICX_K) != 0) {
+		lemph = 2.0;			/* Noticably lighten, but not extreme... */
+		if (dadapt < 0.5)
+			dadapt = 0.5;		/* Partial compensation */
+	}
+
+	/* Deal with ICC, MPP or fallback profile */
+	if ((pdata = new_pcpt(pname, xmask, nmask, &ilimit, &uilimit,
+		                  nemph, demph, lemph, xpow)) == NULL) {
+		error("Perceptual lookup object creation failed");
+	}
+
+	if ((tpdata = new_pcpt(pname, xmask, nmask, &tilimit, &utilimit,
+		                  nemph, demph, lemph, xpow)) == NULL) {
+		error("Perceptual lookup object creation failed");
+	}
+
+	if (verb) {
+		printf("%s test chart\n",ident);
+
+		if (esteps > 0)
+			printf("White patches = %d\n",esteps);
+		if (Bsteps > 0)
+			printf("Black patches = %d\n",Bsteps);
+		if (ssteps > 0)
+			printf("Single channel steps = %d\n",ssteps);
+		if (gsteps > 0)
+			printf("Composite Grey steps = %d\n",gsteps);
+		if (nsteps > 0)
+			printf("Neutral steps = %d\n",nsteps);
+		if (fsteps > 0)
+			printf("Full spread patches = %d\n",fsteps);
+		if (msteps > 0) {
+			if (msurf)
+				printf("Multi-dimention cube surface steps = %d\n",msteps);
+			else
+				printf("Multi-dimention cube steps = %d\n",msteps);
+		}
+		if (bsteps > 0)
+			printf("Multi-dimention body centered cube steps = %d\n",bsteps);
+		if (ilimit >= 0.0)
+			printf("Ink limit = %.1f%% (underlying %.1f%%)\n",ilimit * 100.0, uilimit * 100.0);
+		if (tilimit >= 0.0 && ilimit != tilimit)
+			printf("Text and spacer ink limit = %.1f%% (underlying %.1f%%)\n",tilimit * 100.0, utilimit * 100.0);
+		if (filter) {
+			printf("Filtering out samples outside sphere at %f %f %f radius %f\n",
+					filt[0], filt[1], filt[2], filt[3]);
+		}
+	}
+	pp = new_cgats();	/* Create a CGATS structure */
+	pp->add_other(pp, "CTI1"); 	/* our special type is Calibration Target Information 1 */
+
+	pp->add_table(pp, tt_other, 0);	/* Add the first table for target points */
+	pp->add_table(pp, tt_other, 0);	/* Add the second table for density pre-defined device values */
+	pp->add_table(pp, tt_other, 0);	/* Add the second table for device pre-defined device values */
+	pp->add_kword(pp, 0, "DESCRIPTOR", "Argyll Calibration Target chart information 1",NULL);
+	pp->add_kword(pp, 1, "DESCRIPTOR", "Argyll Calibration Target chart information 1",NULL);
+	pp->add_kword(pp, 2, "DESCRIPTOR", "Argyll Calibration Target chart information 1",NULL);
+	pp->add_kword(pp, 0, "ORIGINATOR", "Argyll targen", NULL);
+	pp->add_kword(pp, 1, "ORIGINATOR", "Argyll targen", NULL);
+	pp->add_kword(pp, 2, "ORIGINATOR", "Argyll targen", NULL);
+	atm[strlen(atm)-1] = '\000';	/* Remove \n from end */
+	pp->add_kword(pp, 0, "CREATED",atm, NULL);
+
+	/* Make available the aproximate white point to allow relative */
+	/* interpretation of the aproximate XYZ values */
+	{
+		int e;
+		double val[MXTD], XYZ[3];
+
+		/* Setup device white */
+		if (nmask & ICX_ADDITIVE)
+			for (e = 0; e < di; e++)
+				val[e] = 1.0;
+		else
+			for (e = 0; e < di; e++)
+				val[e] = 0.0;
+		pdata->dev_to_XYZ(pdata, XYZ, val);		/* Lookup white XYZ */
+
+		sprintf(buf,"%f %f %f", 100.0  * XYZ[0], 100.0 * XYZ[1], 100.0 * XYZ[2]);
+		pp->add_kword(pp, 0, "APPROX_WHITE_POINT", buf, NULL);
+	}
+
+	pp->add_field(pp, 0, "SAMPLE_ID", cs_t);
+	pp->add_field(pp, 1, "INDEX", i_t);			/* Index no. 0..7 in second table */
+	pp->add_field(pp, 2, "INDEX", i_t);			/* Index no. 0..7 in third table */
+
+	/* Setup CGATS fields */
+	{
+		int j;
+		char c_ilimit[20];
+		char *bident = icx_inkmask2char(xmask, 0); 
+
+		for (j = 0; j < di; j++) {
+			int imask;
+			char fname[100];
+
+			imask = icx_index2ink(xmask, j);
+			sprintf(fname,"%s_%s",nmask == ICX_W || nmask == ICX_K ? "GRAY" : bident,
+								  icx_ink2char(imask));
+
+			pp->add_field(pp, 0, fname, r_t);
+			pp->add_field(pp, 1, fname, r_t);
+			pp->add_field(pp, 2, fname, r_t);
+		}
+
+		pp->add_kword(pp, 0, "COLOR_REP", ident, NULL);
+
+		if (ilimit >= 0.0) {
+			sprintf(c_ilimit,"%5.1f",ilimit * 100.0);
+			pp->add_kword(pp, 0, "TOTAL_INK_LIMIT", c_ilimit, NULL);
+		}
+		if (tilimit >= 0.0 && ilimit != tilimit) {
+			sprintf(c_ilimit,"%5.1f",tilimit * 100.0);
+			pp->add_kword(pp, 0, "TEXT_SPACER_TOTAL_INK_LIMIT", c_ilimit, NULL);
+		}
+		free(bident);
+	}
+
+	/* ilimit is assumed to be in a valid range from here on */
+	if (ilimit < 0.0) {
+		uilimit = ilimit = di;	/* default is no limit */
+	}
+
+	if (tilimit < 0.0) {
+		utilimit = tilimit = di;	/* default is no limit */
+	}
+
+	/* Add expected XYZ values to aid previews, scan recognition & strip recognition */
+	pp->add_field(pp, 0, "XYZ_X", r_t);
+	pp->add_field(pp, 0, "XYZ_Y", r_t);
+	pp->add_field(pp, 0, "XYZ_Z", r_t);
+	pp->add_field(pp, 1, "XYZ_X", r_t);
+	pp->add_field(pp, 1, "XYZ_Y", r_t);
+	pp->add_field(pp, 1, "XYZ_Z", r_t);
+	pp->add_field(pp, 2, "XYZ_X", r_t);
+	pp->add_field(pp, 2, "XYZ_Y", r_t);
+	pp->add_field(pp, 2, "XYZ_Z", r_t);
+
+	/* Note if the expected values are expected to be accurate */
+	if (pdata->is_specific(pdata))
+		pp->add_kword(pp, 0, "ACCURATE_EXPECTED_VALUES", "true", NULL);
+
+	if (xpow != 1.0) {
+		sprintf(buf,"%f",xpow);
+		pp->add_kword(pp, 0, "EXTRA_DEV_POW",buf, NULL);
+	}
+
+	if (demph > 1.0) {
+		sprintf(buf,"%f",demph);
+		pp->add_kword(pp, 0, "DARK_REGION_EMPHASIS",buf, NULL);
+	}
+
+	/* Only use optimsed full spread if <= 4 dimensions, else use ifarp */
+	if (di > 4 
+	 && userand == 0		/* Not other high D useful method */
+	 && useqrand == 0
+	 && usedsim == 0
+	 && usepsim == 0)
+		uselat = 1;
+
+	/* Allocate space to record fixed steps */
+	{
+		fxlist_a = 4;
+		if ((fxlist = (fxpos *)malloc(sizeof(fxpos) * fxlist_a)) == NULL)
+		error ("Failed to malloc fxlist");
+	}
+
+
 	/* White color patches */
 	if (esteps > 0)	{
 		int j, e;
@@ -2689,7 +2745,8 @@ int main(int argc, char *argv[]) {
 	/* Add the eight entries in the second table. */
 	/* These are legal device values that we think may */
 	/* give all combinations of min/max CMY density values. */
-	/* These are typically used for DTP51 and DTP41 patch separators. */
+	/* These are chosen from for DTP51, DTP41, i1Pro, ColorMunki etc. */
+	/* patch separators. */
 	{
 		int i;
 
@@ -2709,16 +2766,16 @@ int main(int argc, char *argv[]) {
 			}
 
 			/* Lookup device values for target density */
-			pdata->den_to_dev(pdata, val, den);	
+			tpdata->den_to_dev(tpdata, val, den);	
 
 			/* Do a simple ink limit */
-			if (uilimit < (double)di) {
+			if (utilimit < (double)di) {
 				double tot = 0.0;
 				for (e = 0; e < di; e++)
 					tot += val[e];
-				if (tot > uilimit) {
+				if (tot > utilimit) {
 					for (e = 0; e < di; e++)
-						val[e] *= uilimit/tot;
+						val[e] *= utilimit/tot;
 				}
 			}
 
@@ -2731,7 +2788,7 @@ int main(int argc, char *argv[]) {
 				for (e = 0; e < di; e++)
 					ary[1 + e].d = 100.0 * (1.0 - val[e]);
 			}
-			pdata->dev_to_XYZ(pdata, XYZ, val);		/* Add expected XYZ */
+			tpdata->dev_to_XYZ(tpdata, XYZ, val);		/* Add expected XYZ */
 			ary[1 + di + 0].d = 100.0 * XYZ[0];
 			ary[1 + di + 1].d = 100.0 * XYZ[1];
 			ary[1 + di + 2].d = 100.0 * XYZ[2];
@@ -2802,17 +2859,17 @@ int main(int argc, char *argv[]) {
 			/* If target space isn't something we recognise, convert it */
 			if (ftarg != NULL) {
 				ftarg->dev_to_rLab(ftarg, lab, val);
-				pdata->rLab_to_dev(pdata, val, lab);	
+				tpdata->rLab_to_dev(tpdata, val, lab);	
 			}
 
 			/* Do a simple ink limit */
-			if (uilimit < (double)di) {
+			if (utilimit < (double)di) {
 				double tot = 0.0;
 				for (e = 0; e < di; e++)
 					tot += val[e];
-				if (tot > uilimit) {
+				if (tot > utilimit) {
 					for (e = 0; e < di; e++)
-						val[e] *= uilimit/tot;
+						val[e] *= utilimit/tot;
 				}
 			}
 
@@ -2825,7 +2882,7 @@ int main(int argc, char *argv[]) {
 					ary[1 + e].d = 100.0 * (1.0 - val[e]);
 			}
 
-			pdata->dev_to_XYZ(pdata, XYZ, val);		/* Add expected XYZ */
+			tpdata->dev_to_XYZ(tpdata, XYZ, val);		/* Add expected XYZ */
 			ary[1 + di + 0].d = 100.0 * XYZ[0];
 			ary[1 + di + 1].d = 100.0 * XYZ[1];
 			ary[1 + di + 2].d = 100.0 * XYZ[2];
@@ -2917,6 +2974,7 @@ int main(int argc, char *argv[]) {
 #endif /* VRML_DIAG */
 
 	pdata->del(pdata);	/* Cleanup perceptual conversion */
+	tpdata->del(tpdata);
 
 	free(ident);
 	pp->del(pp);		/* Clean up */
@@ -2928,49 +2986,6 @@ int main(int argc, char *argv[]) {
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - -  */
 
-#ifdef NEVER
-
-/* Compte the display response time */
-static double disprespt2(cgats *pp, int p1, int p2) {
-	double kr, kf;
-	double orgb[3], rgb[3];
-	double xdelay = 0.0;
-	int j;
-
-	kr = DISPLAY_RISE_TIME/log(1 - 0.9);	/* Exponent constant */
-	kf = DISPLAY_FALL_TIME/log(1 - 0.9);	/* Exponent constant */
-
-	orgb[0] = *((double *)pp->t[0].fdata[p1][1 + 0]) / 100.0;
-	orgb[1] = *((double *)pp->t[0].fdata[p1][1 + 1]) / 100.0;
-	orgb[2] = *((double *)pp->t[0].fdata[p1][1 + 2]) / 100.0;
-
-	rgb[0] = *((double *)pp->t[0].fdata[p2][1 + 0]) / 100.0;
-	rgb[1] = *((double *)pp->t[0].fdata[p2][1 + 1]) / 100.0;
-	rgb[2] = *((double *)pp->t[0].fdata[p2][1 + 2]) / 100.0;
-
-	for (j = 0; j < 3; j++) {
-		double el, dl, n, t;
-
-		el = pow(rgb[j], 2.2);
-		dl = el - pow(orgb[j], 2.2);	/* Change in level */
-		if (fabs(dl) > 0.01) {		/* More than 1% change in level */
-			n = DISPLAY_SETTLE_AIM2 * el;
-			if (n < DISPLAY_ABS_AIM2)
-				n = DISPLAY_ABS_AIM2;
-			if (dl > 0.0)
-				t = kr * log(n/dl);
-			else
-				t = kf * log(n/-dl);
-
-			if (t > xdelay)
-				xdelay = t;
-		}
-	}
-	return xdelay;
-}
-
-#endif
-
 /* Compte the display response time */
 static double disprespt(cgats *pp, int p1, int p2) {
 	double orgb[3], nrgb[3];
@@ -2989,3 +3004,5 @@ static double disprespt(cgats *pp, int p1, int p2) {
 	return xdelay;
 }
 
+
+
