@@ -32,7 +32,7 @@
 
 void usage(void) {
 	fprintf(stderr,"Translate colors through an MPP profile, V1.00\n");
-	fprintf(stderr,"Author: Graeme W. Gill\n");
+	fprintf(stderr,"Author: Graeme W. Gill, licensed under the AGPL Version 3\n");
 	fprintf(stderr,"usage: mpplu [-v] [-f func] [-i intent] [-o order] profile\n");
 	fprintf(stderr," -v            Verbose\n");
 	fprintf(stderr," -f function   f = forward, b = backwards\n");
@@ -100,13 +100,14 @@ main(int argc, char *argv[]) {
 
 	icColorSpaceSignature pcsor = icSigLabData;	/* Default */
 	
+
 	error_program = argv[0];
 
 	if (argc < 2)
 		usage();
 
 	/* Process the arguments */
-	for(fa = 1;fa < argc;fa++) {
+	for (fa = 1;fa < argc;fa++) {
 		nfa = fa;					/* skip to nfa if next argument is used */
 		if (argv[fa][0] == '-')	{	/* Look for any flags */
 			char *na = NULL;		/* next argument after flag, null if none */
@@ -220,7 +221,7 @@ main(int argc, char *argv[]) {
 
 					spec = 1;
 					illum = icxIT_custom;
-					if (read_xspect(&cust_illum, &mt, na) != 0)
+					if (read_xspect(&cust_illum, &mt, NULL, na) != 0)
 						usage();
 
 					if (mt != inst_mrt_none
@@ -315,11 +316,12 @@ main(int argc, char *argv[]) {
 	if (fa >= argc || argv[fa][0] == '-') usage();
 	strcpy(prof_name,argv[fa]);
 
+
 	if ((mppo = new_mpp()) == NULL)
 		error ("Creation of MPP object failed");
 
 	if ((rv = mppo->read_mpp(mppo,prof_name)) != 0)
-		error ("%d, %s",rv,mppo->err);
+		error ("%d, %s",rv,mppo->e.m);
 
 	mppo->get_info(mppo, &imask, &devn, &dlimit, &spec_n, &spec_wl_short, &spec_wl_long, NULL, &display);
 	ident = icx_inkmask2char(imask, 1); 
@@ -347,6 +349,7 @@ main(int argc, char *argv[]) {
 		error("Error setting illuminant, observer, or FWA");
 	}
 
+
 	if (test != 0) {
 		printf("!!!!! Running special test code no %d !!!!!\n",test);
 
@@ -414,7 +417,7 @@ main(int argc, char *argv[]) {
 					else
 						fprintf(stdout,"%f",out[j]);
 				}
-				printf(" [%s]\n", icm2str(icmColorSpaceSignature, pcss));
+				printf(" [%s]\n", icm2str(icmColorSpaceSig, pcss));
 
 				/* Print the derivatives */
 				for (i = 0; i < pcsn; i++) {
@@ -558,7 +561,7 @@ main(int argc, char *argv[]) {
 							fprintf(stdout,"%f",out[j]);
 					}
 
-					printf(" [%s]\n", icm2str(icmColorSpaceSignature, pcss));
+					printf(" [%s]\n", icm2str(icmColorSpaceSig, pcss));
 				}
 
 			} else {	/* Do a reverse lookup */
@@ -589,7 +592,7 @@ main(int argc, char *argv[]) {
 					else
 						fprintf(stdout,"%f",in[j]);
 				}
-				printf(" [%s] -> ", icm2str(icmColorSpaceSignature, pcss));
+				printf(" [%s] -> ", icm2str(icmColorSpaceSig, pcss));
 		
 				for (j = 0; j < devn; j++) {
 					if (j > 0)
@@ -720,7 +723,7 @@ char *outname		/* Output VRML/X3D file (no extension) */
 						v2 = v0 | (1 << m2) | (1 << m1);	/* X+Y offset */
 						v3 = v0 | (1 << m1);				/* Y offset */
 
-						/* Linear interp between the main verticies */
+						/* Linear interp between the main vertices */
 						for (j = 0; j < 3; j++) {
 							rgb[j] = (1.0 - yb) * (1.0 - xb) * col[v0][j]
 							       +        yb  * (1.0 - xb) * col[v1][j]
@@ -1263,3 +1266,5 @@ printf("#############################################\n\n\n\n\n\n\n\n");
 
 
 
+
+
