@@ -20,6 +20,7 @@
  */
 
 #include <stdio.h>
+#include <stdarg.h>
 #include <math.h>
 #include "aconfig.h"
 #include "cgats.h"
@@ -225,10 +226,11 @@ static int do_spec(
 
 void usage(void) {
 	fprintf(stderr,"Plot spectrum and calculate CCT and VCT\n");
-	fprintf(stderr,"Author: Graeme W. Gill\n");
+	fprintf(stderr,"Author: Graeme W. Gill, licensed under the AGPL Version 3\n");
 	fprintf(stderr,"usage: specplot [infile.sp]\n");
 	fprintf(stderr," -v               verbose\n");
 	fprintf(stderr," -c               combine multiple files into one plot\n");
+	fprintf(stderr," -n               normalize max level\n");
 	fprintf(stderr," -z               don't make range cover zero\n");
 	fprintf(stderr," -s               don't plot spectra\n");
 	fprintf(stderr," -d I|A|M|T|E     print density values\n");
@@ -239,15 +241,12 @@ void usage(void) {
 	exit(1);
 }
 
-int
-main(
-	int argc,
-	char *argv[]
-) {
+int main(int argc, char *argv[]) {
 	int fa, nfa;			/* argument we're looking at */
 	int k;
 	int verb = 0;
 	int comb = 0;
+	int norm = 0;
 	int zero = 1;
 	int noplot = 0;
 	icxDensityType dens = icxDT_none;
@@ -258,10 +257,11 @@ main(
 	double uvmin = -1.0, uvmax = 1.0;
 	char buf[MAXGRAPHS][200];
 
+
 	error_program = argv[0];
 
 	/* Process the arguments */
-	for(fa = 1;fa < argc;fa++) {
+	for (fa = 1;fa < argc;fa++) {
 		nfa = fa;					/* skip to nfa if next argument is used */
 		if (argv[fa][0] == '-')	{	/* Look for any flags */
 			char *na = NULL;		/* next argument after flag, null if none */
@@ -301,6 +301,9 @@ main(
 			} else if (argv[fa][1] == 'c') {
 				comb = 1;
 
+			} else if (argv[fa][1] == 'n') {
+				norm = 1;
+
 			} else if (argv[fa][1] == 'z') {
 				zero = 0;
 
@@ -343,6 +346,7 @@ main(
 			break;
 	}
 
+
 	if (fa < argc && argv[fa][0] != '-') {	/* Got file arguments */
 		int nsp = 0;		/* Current number in sp[] */
 		int soff = 0;		/* Offset within file */
@@ -364,6 +368,39 @@ main(
 			/* or at least one and we're not combining files and at start of a new file, */
 			/* or at least one and there are no more files */
 			if (nsp >= MAXGRAPHS || (nsp > 0 && ((!comb && soff == 0) || fa >= argc))) {
+				if (norm) {
+					int j;
+					double mlev = 0.0;
+
+					for (i = 0; i < nsp; i++) {
+
+						xspect_denorm(&sp[i]);
+
+						for (j = 0; j < sp[i].spec_n; j++) {
+							if (sp[i].spec[j] > mlev)
+								mlev = sp[i].spec[j];
+						}
+					}
+
+					if (mlev > 1e-6) {
+						for (i = 0; i < nsp; i++) {
+							double mm = 0.0;
+
+							for (j = 0; j < sp[i].spec_n; j++) {
+								if (sp[i].spec[j] > mm)
+									mm = sp[i].spec[j];
+							}
+
+							if (mm > 1e-6) {
+								mm = mlev/mm;
+								for (j = 0; j < sp[i].spec_n; j++) {
+									sp[i].spec[j] *= mm;
+								}
+							}
+						}
+					}
+				}
+
 				/* Plot what we've got */
 				do_spec(buf, sp, nsp, mt, zero, noplot, dens, douv, uvmin, uvmax);
 				nsp = 0;
@@ -466,3 +503,5 @@ main(
 
 
 
+
+
