@@ -42,6 +42,7 @@
 #include "jpeglib.h"
 #include "iccjpeg.h"
 #include "icc.h"
+#include "cgats.h"
 #include "gamut.h"
 #include "xicc.h"
 #include "sort.h"
@@ -54,6 +55,7 @@
 # error "Need to #include fcntl.h!"
 #endif
 
+
 void set_fminmax(double min[3], double max[3]);
 void reset_filter();
 void add_fpixel(double val[3]);
@@ -104,6 +106,8 @@ void usage(void) {
 	fprintf(stderr,"         m:x:y         Mid-tone Adaptation white as x, y\n");
     fprintf(stderr," -x pcent      Expand/compress gamut cylindrically by percent\n");
 	fprintf(stderr," -O outputfile Override the default output filename.\n");
+	fprintf(stderr," [profile.icm | embedded.tif/jpg]     File specifying device to CIE conversion\n");
+	fprintf(stderr," infile1.tif/jpg ...                  One or more raster files to create gamut from\n");
 	exit(1);
 }
 
@@ -345,6 +349,7 @@ main(int argc, char *argv[]) {
 	int rv = 0;
 
 	icc *icco = NULL;
+	icmErr err = { 0, { '\000'} };
 	xicc *xicco = NULL;
 	icxcam *cam = NULL;			/* Separate CAM used for Lab TIFF files */
 	icxViewCond vc;				/* Viewing Condition for CIECAM */
@@ -399,13 +404,14 @@ main(int argc, char *argv[]) {
 
 	double apcsmin[3], apcsmax[3];		/* Actual PCS range */
 
+
 	error_program = argv[0];
 
 	if (argc < 2)
 		usage();
 
 	/* Process the arguments */
-	for(fa = 1;fa < argc;fa++) {
+	for (fa = 1;fa < argc;fa++) {
 		nfa = fa;					/* skip to nfa if next argument is used */
 		if (argv[fa][0] == '-')	{	/* Look for any flags */
 			char *na = NULL;		/* next argument after flag, null if none */
@@ -632,6 +638,7 @@ main(int argc, char *argv[]) {
 	if (fa < (argc-1))
 		strncpy(prof_name,argv[fa++],MAXNAMEL); prof_name[MAXNAMEL] = '\000';
 
+
 	for (ffa = fa; fa < argc; fa++)
 		if (fa >= argc || argv[fa][0] == '-') usage();
 	lfa = fa-1;
@@ -668,8 +675,8 @@ main(int argc, char *argv[]) {
 	
 		if (verb) {
 			icmFile *op;
-			if ((op = new_icmFileStd_fp(stdout)) == NULL)
-				error ("Can't open stdout");
+			if ((op = new_icmFileStd_fp(&err, stdout)) == NULL)
+				error ("Can't open stdout (0x%x, '%s')",err.c,err.m);
 			icco->header->dump(icco->header, op, 1);
 			op->del(op);
 		}
@@ -687,11 +694,11 @@ main(int argc, char *argv[]) {
 	
 		/* Setup the default viewing conditions */
 		if (xicc_enum_viewcond(xicco, &vc, -1, NULL, 0, NULL) == -999)
-			error ("%d, %s",xicco->errc, xicco->err);
+			error ("%d, %s",xicco->e.c, xicco->e.m);
 	
 		if (vc_e != -1)
 			if (xicc_enum_viewcond(xicco, &vc, vc_e, NULL, 0, NULL) == -999)
-				error ("%d, %s",xicco->errc, xicco->err);
+				error ("%d, %s",xicco->e.c, xicco->e.m);
 		if (vc_s >= 0)
 			vc.Ev = vc_s;
 		if (vc_wXYZ[1] > 0.0) {
@@ -753,7 +760,7 @@ main(int argc, char *argv[]) {
 		             | ICX_CAM_NOGAMCLIP
 #endif
 		           , func, intent, pcsor, order, &vc, NULL)) == NULL)
-			error ("%d, %s",xicco->errc, xicco->err);
+			error ("%d, %s",xicco->e.c, xicco->e.m);
 	
 		luo->spaces(luo, &ins, &inn, &outs, &outn, &alg, NULL, NULL, NULL);
 
@@ -827,8 +834,7 @@ main(int argc, char *argv[]) {
 		if ((cam = new_icxcam(cam_default)) == NULL)
 			error("new_icxcam failed");
 
-		cam->set_view(cam, vc.Ev, vc.Wxyz, vc.La, vc.Yb, vc.Lv, vc.Yf, vc.Yg, vc.Gxyz,
-		              XICC_USE_HK, vc.hkscale, vc.mtaf, vc.Wxyz2);
+		cam->set_view_vc(cam, &vc);
 	}
 
 	/* Establish the PCS range if we are filtering */
@@ -869,6 +875,7 @@ main(int argc, char *argv[]) {
 		set_fminmax(pcsmin, pcsmax);
 	}
 
+
 	/* - - - - - - - - - - - - - - - */
 	/* Creat a raster gamut surface */
 	gam = new_gamut(gamres, pcsor == icxSigJabData, 1);
@@ -909,7 +916,7 @@ main(int argc, char *argv[]) {
 			if (luo != NULL) {
 				if (inn != (samplesperpixel-extrasamples))
 					error("TIFF Input file has %d input chanels and is mismatched to colorspace '%s'",
-					       samplesperpixel, icm2str(icmColorSpaceSignature, ins));
+					       samplesperpixel, icm2str(icmColorSpaceSig, ins));
 			}
 
 			if ((tcs = TiffPhotometric2ColorSpaceSignature(&cvt, &sign_mask, photometric,
@@ -919,7 +926,7 @@ main(int argc, char *argv[]) {
 			if (tcs != ins) {
 				if (luo != NULL)
 					error("TIFF photometric '%s' doesn't match ICC input colorspace '%s' !",
-					      Photometric2str(photometric), icm2str(icmColorSpaceSignature,ins));
+					      Photometric2str(photometric), icm2str(icmColorSpaceSig,ins));
 				else
 					error("No profile provided and TIFF photometric '%s' isn't Lab !",
 					      Photometric2str(photometric));
@@ -932,7 +939,7 @@ main(int argc, char *argv[]) {
 			if (verb) {
 				printf("Input TIFF file '%s'\n",in_name);
 				printf("TIFF file photometric is %s\n",Photometric2str(photometric));
-				printf("TIFF file colorspace is %s\n",icm2str(icmColorSpaceSignature,tcs));
+				printf("TIFF file colorspace is %s\n",icm2str(icmColorSpaceSig,tcs));
 				printf("File size %d x %d pixels\n",width,height);
 				printf("\n");
 			}
@@ -1021,16 +1028,16 @@ main(int argc, char *argv[]) {
 			if (luo != NULL) {
 				if (inn != samplesperpixel)
 					error ("JPEG Input file has %d input chanels and is mismatched to colorspace '%s'",
-					       samplesperpixel, icm2str(icmColorSpaceSignature, ins));
+					       samplesperpixel, icm2str(icmColorSpaceSig, ins));
 			}
 
 			if (tcs != ins) {
 				if (luo != NULL)
 					error("JPEG colorspace '%s' doesn't match ICC input colorspace '%s' !",
-					      icm2str(icmColorSpaceSignature, tcs), icm2str(icmColorSpaceSignature,ins));
+					      icm2str(icmColorSpaceSig, tcs), icm2str(icmColorSpaceSig,ins));
 				else
 					error("No profile provided and JPEG colorspace '%s' isn't Lab !",
-					      icm2str(icmColorSpaceSignature, tcs));
+					      icm2str(icmColorSpaceSig, tcs));
 			}
 			jpeg_calc_output_dimensions(&rj);
 			width = rj.output_width;
@@ -1039,7 +1046,7 @@ main(int argc, char *argv[]) {
 			if (verb) {
 				printf("Input JPEG file '%s'\n",in_name);
 				printf("JPEG file original colorspace is %s\n",JPEG_cspace2str(rj.jpeg_color_space));
-				printf("JPEG file colorspace is %s\n",icm2str(icmColorSpaceSignature,tcs));
+				printf("JPEG file colorspace is %s\n",icm2str(icmColorSpaceSig,tcs));
 				printf("File size %d x %d pixels\n",width,height);
 				printf("\n");
 			}
@@ -1113,7 +1120,7 @@ main(int argc, char *argv[]) {
 				if (luo != NULL) {
 //printf("~1 RGB in value = %f %f %f\n",in[0],in[1],in[2]);
 					if ((rv = luo->lookup(luo, out, in)) > 1)
-						error ("%d, %s",icco->errc,icco->err);
+						error ("%d, %s",icco->e.c,icco->e.m);
 //printf("~1 after luo = %f %f %f\n",out[0],out[1],out[2]);
 					
 					if (outs == icSigXYZData) {	/* Convert to Lab */
@@ -1406,3 +1413,5 @@ void del_filter() {
 
 	free(ff);
 }
+
+
