@@ -236,6 +236,9 @@ void xspect_plotNp(xspect *sp[MXGPHS], int n);
 /* Plot up to 12 spectra pointed to by an array */
 void xspect_plotNp_w(xspect *sp[MXGPHS], int n, int wait);
 
+/* Plot up to MXGPHS spectra pointed to by an array, with optional wait and zero */
+void xspect_plotNp_wz(xspect *sp[MXGPHS], int n, int wait, int zero);
+
 /* Plot up to 12 spectra pointed to by an array over a wl range */
 //void xspect_plotNp_w(xspect *sp[MXGPHS], int n, double shwl, double lowl, int wait);
 
